hexsha stringlengths 40 40 | size int64 7 1.05M | ext stringclasses 13
values | lang stringclasses 1
value | max_stars_repo_path stringlengths 4 269 | max_stars_repo_name stringlengths 5 109 | max_stars_repo_head_hexsha stringlengths 40 40 | max_stars_repo_licenses listlengths 1 9 | max_stars_count int64 1 191k ⌀ | max_stars_repo_stars_event_min_datetime stringlengths 24 24 ⌀ | max_stars_repo_stars_event_max_datetime stringlengths 24 24 ⌀ | max_issues_repo_path stringlengths 4 269 | max_issues_repo_name stringlengths 5 116 | max_issues_repo_head_hexsha stringlengths 40 40 | max_issues_repo_licenses listlengths 1 9 | max_issues_count int64 1 48.5k ⌀ | max_issues_repo_issues_event_min_datetime stringlengths 24 24 ⌀ | max_issues_repo_issues_event_max_datetime stringlengths 24 24 ⌀ | max_forks_repo_path stringlengths 4 269 | max_forks_repo_name stringlengths 5 116 | max_forks_repo_head_hexsha stringlengths 40 40 | max_forks_repo_licenses listlengths 1 9 | max_forks_count int64 1 105k ⌀ | max_forks_repo_forks_event_min_datetime stringlengths 24 24 ⌀ | max_forks_repo_forks_event_max_datetime stringlengths 24 24 ⌀ | content stringlengths 7 1.05M | avg_line_length float64 1.21 330k | max_line_length int64 6 990k | alphanum_fraction float64 0.01 0.99 | author_id stringlengths 2 40 |
|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|
7e842698d888fb2eca226b5cb59c0474922ec172 | 1,709 | cpp | C++ | contests/extra-exercices/d.cpp | leomaurodesenv/contest-codes | f7ae7e9d8c67e43dea7ac7dd71afce20d804f518 | [
"MIT"
] | null | null | null | contests/extra-exercices/d.cpp | leomaurodesenv/contest-codes | f7ae7e9d8c67e43dea7ac7dd71afce20d804f518 | [
"MIT"
] | null | null | null | contests/extra-exercices/d.cpp | leomaurodesenv/contest-codes | f7ae7e9d8c67e43dea7ac7dd71afce20d804f518 | [
"MIT"
] | null | null | null | /*
* Problema: D
* ** URL **
*/
#include <iostream>
#include <iomanip>
#include <cstdio>
#include <cstdlib>
#include <numeric>
#include <string>
#include <sstream>
#include <iomanip>
#include <locale>
#include <bitset>
#include <map>
#include <vector>
#include <queue>
#include <stack>
#include <algorithm>
#include <cma... | 24.414286 | 103 | 0.514921 | leomaurodesenv |
7e869285d1a2e8835fafc30e7373b188982c3a6f | 10,771 | hpp | C++ | stdext/small_vector.hpp | timith/stdext | 7c243392d4dfcf4bf1ed0561c18088d393664141 | [
"MIT"
] | null | null | null | stdext/small_vector.hpp | timith/stdext | 7c243392d4dfcf4bf1ed0561c18088d393664141 | [
"MIT"
] | null | null | null | stdext/small_vector.hpp | timith/stdext | 7c243392d4dfcf4bf1ed0561c18088d393664141 | [
"MIT"
] | null | null | null | #pragma once
#include <stddef.h>
#include <cstdlib>
#include <utility>
#include <exception>
#include <algorithm>
#include <initializer_list>
#include <type_traits>
namespace stdext
{
// std::aligned_storage does not support size == 0, so roll our own.
template <typename T, size_t N>
class aligned_buffer
{
public... | 19.946296 | 123 | 0.604122 | timith |
7e9adaa3eaa0bb802d1bfcaa45b3306686045732 | 1,528 | cc | C++ | vm/primordial_soup.cc | Outcue/primordialsoup | 056dd858b011c2f3bc71b9f15240061d1d0760ad | [
"Apache-2.0"
] | 35 | 2016-05-20T03:59:10.000Z | 2022-02-21T09:59:14.000Z | vm/primordial_soup.cc | Outcue/primordialsoup | 056dd858b011c2f3bc71b9f15240061d1d0760ad | [
"Apache-2.0"
] | 7 | 2020-11-22T04:53:24.000Z | 2021-04-18T02:14:09.000Z | vm/primordial_soup.cc | Outcue/primordialsoup | 056dd858b011c2f3bc71b9f15240061d1d0760ad | [
"Apache-2.0"
] | 4 | 2017-02-15T04:26:37.000Z | 2020-11-21T02:29:23.000Z | // Copyright (c) 2017, the Newspeak project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
#include "vm/primordial_soup.h"
#include "vm/flags.h"
#include "vm/globals.h"
#include "vm/isolate.... | 30.56 | 80 | 0.633508 | Outcue |
7e9f1caf978a2addf22c25da1430b6d279480a62 | 5,521 | cpp | C++ | src/ny/common/xkb.cpp | nyorain/ny | 9349a6f668a9458d3a37b76bb3cd1e5c679d16ad | [
"BSL-1.0"
] | 18 | 2015-12-14T09:04:06.000Z | 2021-11-14T20:38:17.000Z | src/ny/common/xkb.cpp | nyorain/ny | 9349a6f668a9458d3a37b76bb3cd1e5c679d16ad | [
"BSL-1.0"
] | 2 | 2015-06-26T09:26:05.000Z | 2019-04-02T09:05:12.000Z | src/ny/common/xkb.cpp | nyorain/ny | 9349a6f668a9458d3a37b76bb3cd1e5c679d16ad | [
"BSL-1.0"
] | 2 | 2017-08-23T06:04:26.000Z | 2019-11-27T01:48:02.000Z | // Copyright (c) 2015-2018 nyorain
// Distributed under the Boost Software License, Version 1.0.
// See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt
#include <ny/common/xkb.hpp>
#include <ny/key.hpp>
#include <nytl/vec.hpp>
#include <nytl/utf.hpp>
#include <nytl/flags.hpp>
#include <xkbc... | 32.28655 | 97 | 0.763449 | nyorain |
7ea3122cd5c8308382126c42951a20076e962995 | 468 | cpp | C++ | test/math/formal_power_series/faulhaber_by_lagrange_interpolation.test.cpp | emthrm/library | 0876ba7ec64e23b5ec476a7a0b4880d497a36be1 | [
"Unlicense"
] | 1 | 2021-12-26T14:17:29.000Z | 2021-12-26T14:17:29.000Z | test/math/formal_power_series/faulhaber_by_lagrange_interpolation.test.cpp | emthrm/library | 0876ba7ec64e23b5ec476a7a0b4880d497a36be1 | [
"Unlicense"
] | 3 | 2020-07-13T06:23:02.000Z | 2022-02-16T08:54:26.000Z | test/math/formal_power_series/faulhaber_by_lagrange_interpolation.test.cpp | emthrm/library | 0876ba7ec64e23b5ec476a7a0b4880d497a36be1 | [
"Unlicense"
] | null | null | null | /*
* @brief 数学/形式的冪級数/ファウルハーバーの公式 ラグランジュ補間版
*/
#define PROBLEM "https://yukicoder.me/problems/no/665"
#include <iostream>
#include "../../../math/modint.hpp"
#include "../../../math/formal_power_series/faulhaber_by_lagrange_interpolation.hpp"
int main() {
using ModInt = MInt<0>;
ModInt::set_mod(10000... | 24.631579 | 85 | 0.638889 | emthrm |
7ea492e8949787f020dc0c1ab72ba99af73cc43b | 308 | hpp | C++ | project1/Print.hpp | Aiosa/PB173 | 9ff8bcd7f0789de48b782ab01a5f0daa021e4d53 | [
"MIT"
] | null | null | null | project1/Print.hpp | Aiosa/PB173 | 9ff8bcd7f0789de48b782ab01a5f0daa021e4d53 | [
"MIT"
] | 1 | 2019-02-19T08:07:13.000Z | 2019-02-19T09:07:11.000Z | project1/Print.hpp | Aiosa/PB173 | 9ff8bcd7f0789de48b782ab01a5f0daa021e4d53 | [
"MIT"
] | null | null | null | #ifndef PRINT_HPP
#define PRINT_HPP
#include <iostream>
#include "ApplicationHelp.hpp"
#include "CommandLineArgument.hpp"
void printCommandLineArgument(const CommandLineArgument &arg, std::ostream &stream);
void printApplicationHelp(const ApplicationHelp &app, std::ostream &stream);
#endif // PRINT_HPP
| 23.692308 | 84 | 0.801948 | Aiosa |
7ea77b097c86101c5df260ee59fd4dd804c1454c | 4,270 | cpp | C++ | source/CompilerDX.cpp | xzrunner/shadertrans | c7480da714b08541cf8de655452fd54725880395 | [
"MIT"
] | 1 | 2021-06-27T22:40:11.000Z | 2021-06-27T22:40:11.000Z | source/CompilerDX.cpp | xzrunner/shadertrans | c7480da714b08541cf8de655452fd54725880395 | [
"MIT"
] | null | null | null | source/CompilerDX.cpp | xzrunner/shadertrans | c7480da714b08541cf8de655452fd54725880395 | [
"MIT"
] | null | null | null | #include "shadertrans/CompilerDX.h"
namespace
{
struct ShaderModel
{
uint8_t major_ver : 6;
uint8_t minor_ver : 2;
uint32_t FullVersion() const noexcept
{
return (major_ver << 2) | minor_ver;
}
bool operator<(const ShaderModel& other) const noexcept
{
return this->FullVer... | 23.333333 | 120 | 0.649883 | xzrunner |
7eabffb2ff4f22d47489cbf385c0893b806a7303 | 1,854 | cpp | C++ | tests/transform_archive.test.cpp | Guekka/libbsarch-cpp | ad435d488e9a816e0109a6f464961d177d3b61f4 | [
"MIT"
] | 1 | 2021-06-16T15:49:07.000Z | 2021-06-16T15:49:07.000Z | tests/transform_archive.test.cpp | Guekka/libbsarch-cpp | ad435d488e9a816e0109a6f464961d177d3b61f4 | [
"MIT"
] | null | null | null | tests/transform_archive.test.cpp | Guekka/libbsarch-cpp | ad435d488e9a816e0109a6f464961d177d3b61f4 | [
"MIT"
] | null | null | null | /* Copyright (C) 2021 G'k
* This Source Code Form is subject to the terms of the Mozilla Public
* License, v. 2.0. If a copy of the MPL was not distributed with this
* file, You can obtain one at https://mozilla.org/MPL/2.0/. */
#include "doctest.h"
#include "bsa_saver.hpp"
#include "transform_archive.hpp"... | 34.981132 | 102 | 0.639159 | Guekka |
9d1ce97012d230c2187112e19f3d72dc7210db24 | 2,315 | hpp | C++ | Pods/OpenVPNAdapter/Sources/OpenVPN3/openvpn/tun/mac/tunutil.hpp | TiagoPedroByterev/openvpnclient-ios | a9dafb2a481cc72a3e408535fb7f0aba9f5cfa76 | [
"MIT"
] | 10 | 2021-03-29T13:52:06.000Z | 2022-03-10T02:24:25.000Z | Pods/OpenVPNAdapter/Sources/OpenVPN3/openvpn/tun/mac/tunutil.hpp | TiagoPedroByterev/openvpnclient-ios | a9dafb2a481cc72a3e408535fb7f0aba9f5cfa76 | [
"MIT"
] | 1 | 2019-07-19T02:40:32.000Z | 2019-07-19T02:40:32.000Z | Pods/OpenVPNAdapter/Sources/OpenVPN3/openvpn/tun/mac/tunutil.hpp | TiagoPedroByterev/openvpnclient-ios | a9dafb2a481cc72a3e408535fb7f0aba9f5cfa76 | [
"MIT"
] | 7 | 2018-07-11T10:37:02.000Z | 2019-08-03T10:34:08.000Z | // OpenVPN -- An application to securely tunnel IP networks
// over a single port, with support for SSL/TLS-based
// session authentication and key exchange,
// packet encryption, packet authentication, and
// packet compression.
//
// Copyright (C) 2012-201... | 30.064935 | 86 | 0.657883 | TiagoPedroByterev |
9d1e992a621864ca66f900437b8fd75f4d368e19 | 398 | cc | C++ | !TbxAppGen/Skeletons/Files/Viewer/src/main.cc | alanbu/tbxappgen | 1b89ad1255c02181a6274231699e4c97ae7081fc | [
"MIT"
] | null | null | null | !TbxAppGen/Skeletons/Files/Viewer/src/main.cc | alanbu/tbxappgen | 1b89ad1255c02181a6274231699e4c97ae7081fc | [
"MIT"
] | null | null | null | !TbxAppGen/Skeletons/Files/Viewer/src/main.cc | alanbu/tbxappgen | 1b89ad1255c02181a6274231699e4c97ae7081fc | [
"MIT"
] | null | null | null |
#include "tbx/application.h"
#include "tbx/autocreatelistener.h"
#include "IconbarHandler.h"
using namespace std;
int main()
{
tbx::Application my_app("<%APPNAME%$Dir>");
// Handler for clicks on iconbar
IconbarHandler iconbar_handler;
// Attach to iconbar resource when it's created
my_app.set_autocr... | 18.952381 | 63 | 0.71608 | alanbu |
9d3bae1d4d9efbc48f739fde5a8931602ed77855 | 2,853 | cpp | C++ | src/MouseReachTestController/MouseReachTestController.cpp | janelia-arduino/MouseReachTestController | f8a075f59da7bd9bfa37dbb0faa7848c2031fee8 | [
"BSD-3-Clause"
] | null | null | null | src/MouseReachTestController/MouseReachTestController.cpp | janelia-arduino/MouseReachTestController | f8a075f59da7bd9bfa37dbb0faa7848c2031fee8 | [
"BSD-3-Clause"
] | null | null | null | src/MouseReachTestController/MouseReachTestController.cpp | janelia-arduino/MouseReachTestController | f8a075f59da7bd9bfa37dbb0faa7848c2031fee8 | [
"BSD-3-Clause"
] | 1 | 2022-03-18T18:56:02.000Z | 2022-03-18T18:56:02.000Z | // ----------------------------------------------------------------------------
// MouseReachTestController.cpp
//
//
// Authors:
// Peter Polidoro peter@polidoro.io
// ----------------------------------------------------------------------------
#include "../MouseReachTestController.h"
using namespace mouse_reach_tes... | 30.031579 | 139 | 0.740974 | janelia-arduino |
9d3d5cf8c80a94fc5fc2d9a2798d22f2de62167a | 4,862 | cpp | C++ | Bomberman/Bomberman/Source/SceneSelectLevel.cpp | allenbateman/SuperFantastics_UPC | d374e62634bf4997f743aa178a5947b6ce548216 | [
"MIT"
] | 2 | 2021-02-22T08:50:27.000Z | 2021-08-19T06:10:46.000Z | Bomberman/Bomberman/Source/SceneSelectLevel.cpp | allenbateman/SuperFantastics_UPC | d374e62634bf4997f743aa178a5947b6ce548216 | [
"MIT"
] | null | null | null | Bomberman/Bomberman/Source/SceneSelectLevel.cpp | allenbateman/SuperFantastics_UPC | d374e62634bf4997f743aa178a5947b6ce548216 | [
"MIT"
] | 2 | 2021-03-04T21:57:18.000Z | 2021-03-06T22:22:56.000Z | #include "SceneSelectLevel.h"
#include "Application.h"
#include "ModuleTextures.h"
#include "ModuleRender.h"
#include "ModuleAudio.h"
#include "ModuleInput.h"
#include "ModuleUI.h"
#include "ModuleFadeToBlack.h"
#include "ModuleLevel.h"
SceneSelectLevel::SceneSelectLevel(bool startEnabled) : Module(startEnabled)
{
}... | 23.375 | 155 | 0.676676 | allenbateman |
9d42521026607f67e0c7f00ef8d093bd60bc1fe9 | 7,364 | cpp | C++ | src/main.cpp | 77Z/Shadow-Native | 80b1f87ae0d81fcb47c951d688d7bc97a5011982 | [
"MIT"
] | null | null | null | src/main.cpp | 77Z/Shadow-Native | 80b1f87ae0d81fcb47c951d688d7bc97a5011982 | [
"MIT"
] | null | null | null | src/main.cpp | 77Z/Shadow-Native | 80b1f87ae0d81fcb47c951d688d7bc97a5011982 | [
"MIT"
] | null | null | null | #include "main.h"
#include "DebugUI.h"
#include "types.h"
#include "shadow/audio.h"
#define GLM_FORCE_RADIANS
#include <glm/glm.hpp>
#include <glm/ext.hpp>
#include <bgfx/bgfx.h>
#include <bx/bx.h>
#include <GLFW/glfw3.h>
#include <cstdio>
#include <imgui_node_editor.h>
#include <imgui_internal.h>
#if BX_PLATFORM_LI... | 27.274074 | 122 | 0.607958 | 77Z |
9d46de9dc2040c7dfcd9bc2332113f05fb1feb67 | 12,176 | hpp | C++ | dorc/analysis.hpp | jsalvadorp/dor | 6506df1ddf8dd7a38fa4071148d3d9738d4bd469 | [
"BSD-3-Clause"
] | 1 | 2016-06-29T21:47:37.000Z | 2016-06-29T21:47:37.000Z | dorc/analysis.hpp | jsalvadorp/dor | 6506df1ddf8dd7a38fa4071148d3d9738d4bd469 | [
"BSD-3-Clause"
] | null | null | null | dorc/analysis.hpp | jsalvadorp/dor | 6506df1ddf8dd7a38fa4071148d3d9738d4bd469 | [
"BSD-3-Clause"
] | null | null | null | #pragma once
#include <unordered_map>
#include <vector>
#include <initializer_list>
#include "ast.hpp"
#include "types.hpp"
using ast::Ptr;
using ast::Atom;
using ast::List;
enum scope_t {
EXTERN,
GLOBAL,
PARAMETER,
LOCAL,
CLOSURE
};
// NOTE consider distinguishing between const and final
en... | 24.59798 | 93 | 0.550591 | jsalvadorp |
9d4c89f5dc1da794e908fdecbc1bd6eb358f9f54 | 1,026 | cpp | C++ | m05/LearnCpp_12/12-1-e_cats_n_dogs3.cpp | dvcchern/CS200 | 333df210e70757da7cec481314b1a1e734fd03ed | [
"MIT"
] | 4 | 2020-02-14T23:54:05.000Z | 2022-01-30T18:29:06.000Z | m05/LearnCpp_12/12-1-e_cats_n_dogs3.cpp | dvcchern/CS200 | 333df210e70757da7cec481314b1a1e734fd03ed | [
"MIT"
] | null | null | null | m05/LearnCpp_12/12-1-e_cats_n_dogs3.cpp | dvcchern/CS200 | 333df210e70757da7cec481314b1a1e734fd03ed | [
"MIT"
] | 6 | 2020-02-24T07:06:47.000Z | 2022-02-03T02:46:46.000Z | #include <string>
#include <iostream>
class Animal {
protected:
std::string m_name;
Animal(std::string name) : m_name(name) { }
public:
std::string getName() { return m_name; }
const char* speak() { return "???"; }
};
class Cat: public Animal{
public:
Cat(std::string name) : Animal(name) { }
const char* sp... | 22.304348 | 63 | 0.554581 | dvcchern |
9d4fb6344082aae55b1c2ef4e11e6afe2c1d11ca | 582 | cpp | C++ | src/language/variables/Boolean.cpp | Countgandi/Quiver | dba0e1d8f2f536dd6cfc95276b049336eda9967d | [
"MIT"
] | 1 | 2021-11-13T04:05:49.000Z | 2021-11-13T04:05:49.000Z | src/language/variables/Boolean.cpp | Countgandi/Quiver | dba0e1d8f2f536dd6cfc95276b049336eda9967d | [
"MIT"
] | null | null | null | src/language/variables/Boolean.cpp | Countgandi/Quiver | dba0e1d8f2f536dd6cfc95276b049336eda9967d | [
"MIT"
] | null | null | null | //
// Created by Seth H. on 11/8/2021.
//
#include "Boolean.h"
bool Boolean::isType(const std::string& type) const {
if(type == "boolean") {
return true;
}
return false;
}
bool Boolean::canParseData(const std::string& value) const {
if(value == "null" || value == "true" || value == "false" ||... | 23.28 | 177 | 0.539519 | Countgandi |
9d5770ee91ea446c96f32c47bc49b71a755406a9 | 463 | hpp | C++ | Engine/Header/Render/Gizmos/CGizmosPointLight.hpp | Aredhele/OOM-Engine | e52f706d17f1867f575a85ba5b87b4cc34a7fa97 | [
"MIT"
] | 9 | 2018-07-21T00:30:35.000Z | 2021-09-04T02:54:11.000Z | Engine/Header/Render/Gizmos/CGizmosPointLight.hpp | Aredhele/OOM-Engine | e52f706d17f1867f575a85ba5b87b4cc34a7fa97 | [
"MIT"
] | null | null | null | Engine/Header/Render/Gizmos/CGizmosPointLight.hpp | Aredhele/OOM-Engine | e52f706d17f1867f575a85ba5b87b4cc34a7fa97 | [
"MIT"
] | 1 | 2021-12-03T14:12:41.000Z | 2021-12-03T14:12:41.000Z | /// \file CGizmosPointLight.hpp
/// \date 03/08/2018
/// \project OOM-Engine
/// \package Render/Gizmos
/// \author Vincent STEHLY--CALISTO
#ifndef OOM_ENGINE_C_GIZMOS_POINT_LIGHT_HPP__
#define OOM_ENGINE_C_GIZMOS_POINT_LIGHT_HPP__
#include <GLM/glm.hpp>
namespace Oom {
void DrawPointLight(glm... | 25.722222 | 113 | 0.736501 | Aredhele |
9d58bd6cfeec56e713a609992366b6be8c13c465 | 1,147 | cpp | C++ | tests/unit/appc/schema/test_ac_name.cpp | cdaylward/libappc | 4f7316b584d92a110198a3f1573c170e5492194c | [
"Apache-2.0"
] | 63 | 2015-01-20T18:35:27.000Z | 2021-11-16T10:53:40.000Z | tests/unit/appc/schema/test_ac_name.cpp | Manu343726/libappc | 8d181ef4ee80c8f1bcbf6ca04cf66e04e5e5bc8a | [
"Apache-2.0"
] | 5 | 2015-01-20T17:28:54.000Z | 2015-02-09T17:36:54.000Z | tests/unit/appc/schema/test_ac_name.cpp | cdaylward/libappc | 4f7316b584d92a110198a3f1573c170e5492194c | [
"Apache-2.0"
] | 12 | 2015-01-26T04:37:08.000Z | 2020-11-14T02:19:13.000Z | #include "gtest/gtest.h"
#include "appc/schema/ac_name.h"
using namespace appc::schema;
struct TestName : ACName<TestName> {
explicit TestName(const std::string& name)
: ACName<TestName>(name) {}
};
TEST(ACName, empty) {
ASSERT_FALSE(TestName::from_json("")->validate());
}
TEST(ACName, rfc1123) {
ASSERT_T... | 33.735294 | 71 | 0.695728 | cdaylward |
9d60082e5ef279c4c621a02cbd6c0fcffbae5918 | 1,356 | cpp | C++ | 132-palindrome-partitioning-ii/palindrome-partitioning-ii.cpp | TJUSsr/leetcodesolution | 8244de2d76c9e8e5b9d98dd1e8efed4d680d44ee | [
"MIT"
] | null | null | null | 132-palindrome-partitioning-ii/palindrome-partitioning-ii.cpp | TJUSsr/leetcodesolution | 8244de2d76c9e8e5b9d98dd1e8efed4d680d44ee | [
"MIT"
] | 2 | 2021-03-31T19:10:41.000Z | 2021-12-13T19:58:15.000Z | 132-palindrome-partitioning-ii/palindrome-partitioning-ii.cpp | TJUSsr/leetcodesolution | 8244de2d76c9e8e5b9d98dd1e8efed4d680d44ee | [
"MIT"
] | null | null | null | // Given a string s, partition s such that every substring of the partition is a palindrome.
//
// Return the minimum cuts needed for a palindrome partitioning of s.
//
// Example:
//
//
// Input: "aab"
// Output: 1
// Explanation: The palindrome partitioning ["aa","b"] could be produced using 1 cut.
//
//
clas... | 29.478261 | 93 | 0.469027 | TJUSsr |
9d67c577dea5d0200ec9054ec05b38ebdd056724 | 36,526 | cpp | C++ | src/projectrtpchannel.cpp | tinpotnick/projectrtp | 6f3b6ea651addc1a90339debcec77f6071f6d3e8 | [
"MIT"
] | null | null | null | src/projectrtpchannel.cpp | tinpotnick/projectrtp | 6f3b6ea651addc1a90339debcec77f6071f6d3e8 | [
"MIT"
] | 4 | 2021-07-12T14:21:37.000Z | 2022-01-17T14:43:52.000Z | src/projectrtpchannel.cpp | tinpotnick/projectrtp | 6f3b6ea651addc1a90339debcec77f6071f6d3e8 | [
"MIT"
] | null | null | null |
#include <iostream>
#include <cstdlib>
#include <boost/bind/bind.hpp>
#include <boost/chrono.hpp>
#include <iomanip>
#include <utility>
#include "projectrtpchannel.h"
#include "controlclient.h"
/*
# channelrecorder
c'stor and create
Track files we are recording to.
*/
channelrecorder::channelrecorder( std::string... | 26.127325 | 213 | 0.609675 | tinpotnick |
9d6fb371a47fa153ea2edbf17e886b7522731e31 | 584 | cpp | C++ | GameEngine_Prototype/GameEngine_Prototype/FontLibrary.cpp | Michaelwolf95/CECS_491_GameEngine_Prototype | d134fa376484d1115bf5af75f062ef44c8e70263 | [
"MIT"
] | 2 | 2019-10-14T03:45:55.000Z | 2020-07-12T08:08:54.000Z | GameEngine_Prototype/GameEngine_Prototype/FontLibrary.cpp | Michaelwolf95/CECS_491_GameEngine_Prototype | d134fa376484d1115bf5af75f062ef44c8e70263 | [
"MIT"
] | null | null | null | GameEngine_Prototype/GameEngine_Prototype/FontLibrary.cpp | Michaelwolf95/CECS_491_GameEngine_Prototype | d134fa376484d1115bf5af75f062ef44c8e70263 | [
"MIT"
] | 1 | 2019-09-02T03:34:28.000Z | 2019-09-02T03:34:28.000Z | #include "FontLibrary.h"
#include "Text.h"
FontLibrary::FontLibrary()
{
}
FontLibrary::~FontLibrary()
{
}
void FontLibrary::LoadAssetIntoLibrary(Text t)
{
Text* loadedText = &t;
library.insert({ t.fontPath , loadedText });
std::cout << "Hello World" << library.size() << "Bye World" << std::endl;
}
Text *& F... | 16.685714 | 74 | 0.664384 | Michaelwolf95 |
9d73349fe790f4400f0d96ebfcd1ace084508c51 | 27,048 | cpp | C++ | utils/pmachine-llvm/Passes/MutateCallIntrinsicsPass.cpp | e-katz/SCI | 7a0cfc0518b15c54647bb1527a8192da8521b35b | [
"Apache-2.0"
] | 5 | 2020-11-22T07:07:36.000Z | 2022-01-08T21:11:21.000Z | utils/pmachine-llvm/Passes/MutateCallIntrinsicsPass.cpp | e-katz/sci | 7a0cfc0518b15c54647bb1527a8192da8521b35b | [
"Apache-2.0"
] | 1 | 2021-11-06T19:39:52.000Z | 2021-11-07T21:15:23.000Z | utils/pmachine-llvm/Passes/MutateCallIntrinsicsPass.cpp | ekatz/sci | 7a0cfc0518b15c54647bb1527a8192da8521b35b | [
"Apache-2.0"
] | null | null | null | //===- Passes/MutateCallIntrinsicsPass.cpp --------------------------------===//
//
// SPDX-License-Identifier: Apache-2.0
//
//===----------------------------------------------------------------------===//
#include "MutateCallIntrinsicsPass.hpp"
#include "../Decl.hpp"
#include "../Method.hpp"
#include "../Object.hpp"... | 39.835052 | 80 | 0.481034 | e-katz |
9d74619207f61038a4bf0e3a7f65eb3ce193d583 | 1,847 | cpp | C++ | avanzado/plantillas.cpp | jrinconada/cpp-examples | 069e3cc910b2c2d0716af36bef28336003fb6d9e | [
"MIT"
] | 1 | 2018-02-22T12:33:44.000Z | 2018-02-22T12:33:44.000Z | avanzado/plantillas.cpp | jrinconada/cpp-examples | 069e3cc910b2c2d0716af36bef28336003fb6d9e | [
"MIT"
] | null | null | null | avanzado/plantillas.cpp | jrinconada/cpp-examples | 069e3cc910b2c2d0716af36bef28336003fb6d9e | [
"MIT"
] | null | null | null | #include <iostream>
#include <math.h>
/* Función genérica
template indica que se va a crear una platilla
typename define el nombre del tipo de dato T
T se cambia en tiempo de compilación por un tipo de dato concreto
El código de la función se genera en tiempo de compilación */
template <typename T> //... | 26.768116 | 92 | 0.642664 | jrinconada |
9d7ae9053883996ceadda0f5062360775658b570 | 3,677 | hpp | C++ | sycl2020/library/src/device/maxangle.hpp | xfong/sycl | 405397e7bd030d104c5c88f403a617b6e8c3429a | [
"MIT"
] | 1 | 2021-06-15T02:42:29.000Z | 2021-06-15T02:42:29.000Z | sycl2020/library/src/device/maxangle.hpp | xfong/sycl | 405397e7bd030d104c5c88f403a617b6e8c3429a | [
"MIT"
] | null | null | null | sycl2020/library/src/device/maxangle.hpp | xfong/sycl | 405397e7bd030d104c5c88f403a617b6e8c3429a | [
"MIT"
] | null | null | null | // setmaxangle kernel
#include "include/utils.h"
#include "include/device_function.hpp"
// device side function. This is essentially the function of the kernel
// See maxangle.go for more details.
template <typename dataT>
void setmaxangle_fcn(sycl::nd_item<3> item,
dataT* dst,
... | 31.973913 | 89 | 0.48953 | xfong |
9d7dc177328e6d8bca23b0e77746872e3a3ea3af | 3,408 | hpp | C++ | include/GlobalNamespace/LocalizationProvider.hpp | darknight1050/BeatSaber-Quest-Codegen | a6eeecc3f0e8f6079630f9a9a72b3121ac7b2032 | [
"Unlicense"
] | null | null | null | include/GlobalNamespace/LocalizationProvider.hpp | darknight1050/BeatSaber-Quest-Codegen | a6eeecc3f0e8f6079630f9a9a72b3121ac7b2032 | [
"Unlicense"
] | null | null | null | include/GlobalNamespace/LocalizationProvider.hpp | darknight1050/BeatSaber-Quest-Codegen | a6eeecc3f0e8f6079630f9a9a72b3121ac7b2032 | [
"Unlicense"
] | null | null | null | // Autogenerated from CppHeaderCreator
// Created by Sc2ad
// =========================================================================
#pragma once
// Begin includes
#include "extern/beatsaber-hook/shared/utils/typedefs.h"
// Including type: UnityEngine.ScriptableObject
#include "UnityEngine/ScriptableObject.hp... | 48 | 137 | 0.726526 | darknight1050 |
9d85e12d738a2f25407e1c6aedf2d4ed2d7d3c84 | 110 | cpp | C++ | contest/AtCoder/abc138/A.cpp | not522/Competitive-Programming | be4a7d25caf5acbb70783b12899474a56c34dedb | [
"Unlicense"
] | 7 | 2018-04-14T14:55:51.000Z | 2022-01-31T10:49:49.000Z | contest/AtCoder/abc138/A.cpp | not522/Competitive-Programming | be4a7d25caf5acbb70783b12899474a56c34dedb | [
"Unlicense"
] | 5 | 2018-04-14T14:28:49.000Z | 2019-05-11T02:22:10.000Z | contest/AtCoder/abc138/A.cpp | not522/Competitive-Programming | be4a7d25caf5acbb70783b12899474a56c34dedb | [
"Unlicense"
] | null | null | null | #include "string.hpp"
int main() {
int a(in);
String s(in);
cout << (a >= 3200 ? s : "red") << endl;
}
| 13.75 | 42 | 0.5 | not522 |
9d8e017d42c8ba41d72545e1b5d0c99c69253b2e | 84 | cpp | C++ | KGE/Core/Interface/ComponentButton.cpp | jkeywo/KGE | 5ad2619a4e205dd549cdf638854db356a80694ea | [
"MIT"
] | 1 | 2016-08-10T14:03:29.000Z | 2016-08-10T14:03:29.000Z | KGE/Core/Interface/ComponentButton.cpp | jkeywo/KGE | 5ad2619a4e205dd549cdf638854db356a80694ea | [
"MIT"
] | null | null | null | KGE/Core/Interface/ComponentButton.cpp | jkeywo/KGE | 5ad2619a4e205dd549cdf638854db356a80694ea | [
"MIT"
] | null | null | null | #include "KGE.hpp"
#include "Core/Interface/ComponentButton.hpp"
namespace KGE
{
}; | 14 | 45 | 0.75 | jkeywo |
9d8fc48434f47ca8e3d531b0008f8217f815fa85 | 598 | cpp | C++ | src/universe/vehicle/PackedVehicle.cpp | Ghimli/new-ospgl | 31bd84e52d954683671211ff16ce8702bdb87312 | [
"MIT",
"BSD-3-Clause"
] | 22 | 2019-11-15T22:07:17.000Z | 2022-01-13T16:40:01.000Z | src/universe/vehicle/PackedVehicle.cpp | Ghimli/new-ospgl | 31bd84e52d954683671211ff16ce8702bdb87312 | [
"MIT",
"BSD-3-Clause"
] | 25 | 2020-03-03T00:54:21.000Z | 2021-12-30T16:24:22.000Z | src/universe/vehicle/PackedVehicle.cpp | Ghimli/new-ospgl | 31bd84e52d954683671211ff16ce8702bdb87312 | [
"MIT",
"BSD-3-Clause"
] | 3 | 2020-03-04T00:36:13.000Z | 2020-06-01T20:53:51.000Z | #include "PackedVehicle.h"
#include "Vehicle.h"
PackedVehicle::PackedVehicle(Vehicle* v)
{
this->vehicle = v;
}
void PackedVehicle::set_world_state(WorldState n_state)
{
root_state = n_state;
// Calculate new root
root_transform.setOrigin(to_btVector3(root_state.cartesian.pos));
root_transform.setRotation(to_b... | 19.290323 | 67 | 0.722408 | Ghimli |
9d98d57acf1c1070bd21fa9cb39b642177c85bb7 | 26,541 | cpp | C++ | src/DynamicInterpolation/GetInterpolatedValues.cpp | csyzzkdcz/PhaseInterpolation_polyscope | 4833a569f9eca1c222f7cdfd8e4aae3f03d8ad0b | [
"MIT"
] | null | null | null | src/DynamicInterpolation/GetInterpolatedValues.cpp | csyzzkdcz/PhaseInterpolation_polyscope | 4833a569f9eca1c222f7cdfd8e4aae3f03d8ad0b | [
"MIT"
] | null | null | null | src/DynamicInterpolation/GetInterpolatedValues.cpp | csyzzkdcz/PhaseInterpolation_polyscope | 4833a569f9eca1c222f7cdfd8e4aae3f03d8ad0b | [
"MIT"
] | null | null | null | #include <tbb/blocked_range.h>
#include <tbb/parallel_for.h>
#include <iostream>
#include <iomanip>
#ifndef GRAIN_SIZE
#define GRAIN_SIZE 10
#endif
#include "../../include/DynamicInterpolation/GetInterpolatedValues.h"
Eigen::MatrixXd GetInterpolatedValues::SPDProjection(Eigen::MatrixXd A)
{
Eigen::MatrixXd posHe... | 38.298701 | 233 | 0.560152 | csyzzkdcz |
9d9d6b71b65c33884ee9aa237807ae90878d75c9 | 1,217 | cpp | C++ | Civilizations/EManCreate.cpp | dohxehapo/Civilizations | 84f44c16e012c65c95e213efb98c06ae298400f1 | [
"MIT"
] | 1 | 2018-08-11T18:45:01.000Z | 2018-08-11T18:45:01.000Z | Civilizations/EManCreate.cpp | WowSoLaggy/Civilizations | 84f44c16e012c65c95e213efb98c06ae298400f1 | [
"MIT"
] | null | null | null | Civilizations/EManCreate.cpp | WowSoLaggy/Civilizations | 84f44c16e012c65c95e213efb98c06ae298400f1 | [
"MIT"
] | null | null | null | #include "stdafx.h"
#include "EManager.h"
int EManager::m_nextId = 1;
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// General
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
void EManager::InitializeEntity(Entity &pEntity)
{
pEntity... | 27.044444 | 87 | 0.506163 | dohxehapo |
9da3fd470883f8428309bc96a3ef5f6ee3e2ea2a | 9,949 | cc | C++ | naos/src/kernel/task/builtin/input_task.cc | kadds/NaOS | ea5eeed6f777b8f62acf3400b185c94131b6e1f0 | [
"BSD-3-Clause"
] | 14 | 2020-02-12T11:07:58.000Z | 2022-02-02T00:05:08.000Z | naos/src/kernel/task/builtin/input_task.cc | kadds/NaOS | ea5eeed6f777b8f62acf3400b185c94131b6e1f0 | [
"BSD-3-Clause"
] | null | null | null | naos/src/kernel/task/builtin/input_task.cc | kadds/NaOS | ea5eeed6f777b8f62acf3400b185c94131b6e1f0 | [
"BSD-3-Clause"
] | 4 | 2020-02-27T09:53:53.000Z | 2021-11-07T17:43:44.000Z | #include "kernel/task/builtin/input_task.hpp"
#include "kernel/common/cursor/cursor.hpp"
#include "kernel/dev/tty/tty.hpp"
#include "kernel/fs/vfs/file.hpp"
#include "kernel/fs/vfs/vfs.hpp"
#include "kernel/input/key.hpp"
#include "kernel/io/io_manager.hpp"
#include "kernel/mm/new.hpp"
#include "kernel/signal.hpp"
#inc... | 35.405694 | 119 | 0.539552 | kadds |
9da44f1cb04c2f8467bdd5636ea32010edcb4bb3 | 10,285 | cpp | C++ | src/widgets/dialogs/SelectChannelDialog.cpp | devolution2409/chatterino2 | 978931bcfc40bae63f65c18e7a3274c77c0f45ca | [
"MIT"
] | null | null | null | src/widgets/dialogs/SelectChannelDialog.cpp | devolution2409/chatterino2 | 978931bcfc40bae63f65c18e7a3274c77c0f45ca | [
"MIT"
] | null | null | null | src/widgets/dialogs/SelectChannelDialog.cpp | devolution2409/chatterino2 | 978931bcfc40bae63f65c18e7a3274c77c0f45ca | [
"MIT"
] | null | null | null | #include "SelectChannelDialog.hpp"
#include "Application.hpp"
#include "providers/twitch/TwitchServer.hpp"
#include "util/LayoutCreator.hpp"
#include "widgets/Notebook.hpp"
#include <QDialogButtonBox>
#include <QGroupBox>
#include <QLabel>
#include <QLineEdit>
#include <QVBoxLayout>
#define TAB_TWITCH 0... | 36.471631 | 101 | 0.589791 | devolution2409 |
9da46691020b381437833de7da131c04a3ada5c1 | 1,159 | cpp | C++ | src/homework/tic_tac_toe/tic_tac_toe_manager.cpp | JasonsTortaReviews/acc-cosc-1337-spring-2021-JasonsTortaReviews | 737ba127dcc11858883474e6be6685db2767315d | [
"MIT"
] | null | null | null | src/homework/tic_tac_toe/tic_tac_toe_manager.cpp | JasonsTortaReviews/acc-cosc-1337-spring-2021-JasonsTortaReviews | 737ba127dcc11858883474e6be6685db2767315d | [
"MIT"
] | null | null | null | src/homework/tic_tac_toe/tic_tac_toe_manager.cpp | JasonsTortaReviews/acc-cosc-1337-spring-2021-JasonsTortaReviews | 737ba127dcc11858883474e6be6685db2767315d | [
"MIT"
] | 1 | 2021-02-05T02:56:37.000Z | 2021-02-05T02:56:37.000Z | //cpp
#include "tic_tac_toe_manager.h"
#include "tic_tac_toe.h"
void TicTacToeManager::saved_games(std::unique_ptr<TicTacToe> &b)
{
update_winner_count(b -> get_winner());
games.push_back(std::move(b));
}
ostream& operator << (ostream& out, const TicTacToeManager& manager)
{
for(auto &juego : manager.games)
{
... | 17.298507 | 70 | 0.640207 | JasonsTortaReviews |
9db094a5300eaf9391e0f6528e8d0550f66eb4a6 | 627 | hpp | C++ | src/roerei/normalize.hpp | Wassasin/roerei | 78a6b91819cc37fd7ac25a209f18a3f97c5db2f5 | [
"BSD-3-Clause"
] | 1 | 2019-02-11T14:57:25.000Z | 2019-02-11T14:57:25.000Z | src/roerei/normalize.hpp | Wassasin/roerei | 78a6b91819cc37fd7ac25a209f18a3f97c5db2f5 | [
"BSD-3-Clause"
] | null | null | null | src/roerei/normalize.hpp | Wassasin/roerei | 78a6b91819cc37fd7ac25a209f18a3f97c5db2f5 | [
"BSD-3-Clause"
] | null | null | null | #pragma once
namespace roerei
{
class normalize
{
public:
static void exec(std::vector<std::pair<dependency_id_t, float>>& suggestions)
{
if(suggestions.size() == 0)
return;
auto it = suggestions.begin();
float min = it->second;
float max = it->second;
for(it++; it != suggestions.end(); it++)
{
m... | 18.441176 | 87 | 0.610845 | Wassasin |
9db697b16487b6328ee938aff50e49fbd7edeb9a | 4,694 | cpp | C++ | editor/ui/console.cpp | ArcheGraphics/Arche-cpp | da6770edd4556a920b3f7298f38176107caf7e3a | [
"MIT"
] | 8 | 2022-02-15T12:54:57.000Z | 2022-03-30T16:35:58.000Z | editor/ui/console.cpp | yangfengzzz/DigitalArche | da6770edd4556a920b3f7298f38176107caf7e3a | [
"MIT"
] | null | null | null | editor/ui/console.cpp | yangfengzzz/DigitalArche | da6770edd4556a920b3f7298f38176107caf7e3a | [
"MIT"
] | null | null | null | // Copyright (c) 2022 Feng Yang
//
// I am making my contributions/submissions to this project solely in my
// personal capacity and am not conveying any rights to any intellectual
// property of any third parties.
#include "console.h"
#include "ui/widgets/buttons/button_simple.h"
#include "ui/widgets/selection/c... | 30.283871 | 108 | 0.632936 | ArcheGraphics |
e38b132ad73938fcd0a6cf629d87f0f51e3258ae | 716 | cpp | C++ | b/b936_map_TLE.cpp | mirkat1206/zerojudge_cpp | 263cd51f4eee4acec8396f6c069bba540ac15e96 | [
"BSD-2-Clause"
] | 1 | 2019-12-27T03:03:50.000Z | 2019-12-27T03:03:50.000Z | b/b936_map_TLE.cpp | mirkat1206/zerojudge_cpp | 263cd51f4eee4acec8396f6c069bba540ac15e96 | [
"BSD-2-Clause"
] | null | null | null | b/b936_map_TLE.cpp | mirkat1206/zerojudge_cpp | 263cd51f4eee4acec8396f6c069bba540ac15e96 | [
"BSD-2-Clause"
] | null | null | null | // b936: Kevin 愛橘子
/* NOTE : this code will TLE */
#include <cstdio>
#include <map>
using namespace std;
#define LLI long long int
#define MAP map<long long int,long long int>
MAP ans;
LLI foo(LLI n, LLI m)
{
if( ans.find(n)!=ans.end() )
return ans[n] ;
if( n<m )
ans.insert( pair<LLI,LLI>( n ... | 17.9 | 78 | 0.509777 | mirkat1206 |
e38b75696bb9045ceb95822eb379f3283783adad | 1,048 | cpp | C++ | src/hfsm/hfsmtransition.cpp | mamontov-cpp/saddy | f20a0030e18af9e0714fe56c19407fbeacc529a7 | [
"BSD-2-Clause"
] | 58 | 2015-08-09T14:56:35.000Z | 2022-01-15T22:06:58.000Z | src/hfsm/hfsmtransition.cpp | mamontov-cpp/saddy-graphics-engine-2d | e25a6637fcc49cb26614bf03b70e5d03a3a436c7 | [
"BSD-2-Clause"
] | 245 | 2015-08-08T08:44:22.000Z | 2022-01-04T09:18:08.000Z | src/hfsm/hfsmtransition.cpp | mamontov-cpp/saddy | f20a0030e18af9e0714fe56c19407fbeacc529a7 | [
"BSD-2-Clause"
] | 23 | 2015-12-06T03:57:49.000Z | 2020-10-12T14:15:50.000Z | #include "hfsm/hfsmtransitionrepository.h"
#include "hfsm/hfsmtransition.h"
#include "hfsm/hfsmhandler.h"
#include "db/dbtypename.h"
#include <string.h>
sad::hfsm::Transition::Transition() : m_repository(nullptr)
{
}
sad::hfsm::Transition::~Transition()
{
}
void sad::hfsm::Transition::setReposi... | 18.385965 | 100 | 0.631679 | mamontov-cpp |
e38bd6ef1fb4a85f84c724833169645933a32786 | 2,518 | hpp | C++ | msj_archives/code/Msj1296.src/Thin Client/ChatApp.hpp | sarangbaheti/misc-code | d47a8d1cc41f19701ce628c9f15976bb5baa239d | [
"Unlicense"
] | 1 | 2020-10-22T12:58:55.000Z | 2020-10-22T12:58:55.000Z | msj_archives/code/Msj1296.src/Thin Client/ChatApp.hpp | sarangbaheti/misc-code | d47a8d1cc41f19701ce628c9f15976bb5baa239d | [
"Unlicense"
] | null | null | null | msj_archives/code/Msj1296.src/Thin Client/ChatApp.hpp | sarangbaheti/misc-code | d47a8d1cc41f19701ce628c9f15976bb5baa239d | [
"Unlicense"
] | 2 | 2020-10-19T23:36:26.000Z | 2020-10-22T12:59:37.000Z | // ChatApp.hpp
// Header Generated By ViewSoft
// Portions Copyright (c) 1992-1996 ViewSoft, Inc. All Rights Reserved.
#ifdef EOS_STRICT_INCLUDE
#ifdef CHATAPP_HPP
#error file already included
#endif
#endif
#ifndef CHATAPP_HPP
#define CHATAPP_HPP
#ifndef FRAMEWK_HPP
#include <framewk.hpp>
#endif
// classnam... | 37.029412 | 81 | 0.489674 | sarangbaheti |
e391fdca276026ef8175b35710a213b2c04b3fae | 3,809 | cc | C++ | moui/ui/android/view_android.cc | ollix/moui | 4a931aa15fac42b308baae170a855c2d78f9ee9f | [
"Apache-2.0"
] | 59 | 2015-01-23T01:02:50.000Z | 2021-11-26T00:01:45.000Z | moui/ui/android/view_android.cc | ollix/moui | 4a931aa15fac42b308baae170a855c2d78f9ee9f | [
"Apache-2.0"
] | 2 | 2017-05-26T15:26:24.000Z | 2020-09-25T03:54:01.000Z | moui/ui/android/view_android.cc | ollix/moui | 4a931aa15fac42b308baae170a855c2d78f9ee9f | [
"Apache-2.0"
] | 7 | 2015-09-25T08:09:20.000Z | 2019-11-24T15:24:28.000Z | // Copyright (c) 2014 Ollix. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable ... | 40.094737 | 79 | 0.704122 | ollix |
e39203f180836ef9933b6fb916dba267b0eed4e1 | 1,947 | cpp | C++ | src/abc_stream.cpp | FirestonnneTFM/tfm_key_parser | ff5c428dae8136d65f0238ae5269228fbe581ad3 | [
"MIT"
] | 3 | 2018-09-11T10:33:44.000Z | 2019-12-14T20:32:36.000Z | src/abc_stream.cpp | FirestonnneTFM/tfm_key_parser | ff5c428dae8136d65f0238ae5269228fbe581ad3 | [
"MIT"
] | 2 | 2018-06-24T08:00:58.000Z | 2022-02-24T00:21:07.000Z | src/abc_stream.cpp | FirestonnneTFM/tfm_key_parser | ff5c428dae8136d65f0238ae5269228fbe581ad3 | [
"MIT"
] | null | null | null | #include "abc_stream.hpp"
abc_stream::abc_stream() {
data = nullptr;
ptr = nullptr;
}
abc_stream::abc_stream(uint8_t *dat) {
data = dat;
ptr = dat;
}
void abc_stream::undo() {
--ptr;
}
uint8_t abc_stream::next() {
uint8_t value = *ptr;
ptr += 1;
return value;
}
uint8_t abc_stream::peek() {
return *ptr;
}
... | 15.829268 | 57 | 0.568567 | FirestonnneTFM |
e39f52abeb3f50e15001c5288cff18fb731d97cf | 1,728 | cpp | C++ | Esercizi/snake.cpp | leouzz/Informatica-C- | 32ac6b93e75350578ab1fc5a37bd7bf2e61373e5 | [
"Apache-2.0"
] | null | null | null | Esercizi/snake.cpp | leouzz/Informatica-C- | 32ac6b93e75350578ab1fc5a37bd7bf2e61373e5 | [
"Apache-2.0"
] | null | null | null | Esercizi/snake.cpp | leouzz/Informatica-C- | 32ac6b93e75350578ab1fc5a37bd7bf2e61373e5 | [
"Apache-2.0"
] | null | null | null | #include <iostream>
#include <cstdlib>
#include <unistd.h>
using namespace std;
const int altezza = 20;
const int lunghezza = 20;
int testaX, testaY;
int fruttoX, fruttoY;
int tastiera();
void fruttolo();
void disegna();
void logica();
int tastiera(){
int dir = 0;
if (kbhit()){
char key;
ke... | 17.632653 | 63 | 0.446759 | leouzz |
e3a1a26e4470692b13373559c9cc934d37ca31ff | 658 | cpp | C++ | Linked Lists/Remove Duplicates From Sorted List.cpp | 1aman1/practice-InterviewBit | cafb841bd57f74f8fc3690a7f7830e6ca9fda916 | [
"MIT"
] | 1 | 2019-08-14T05:46:57.000Z | 2019-08-14T05:46:57.000Z | Linked Lists/Remove Duplicates From Sorted List.cpp | 1aman1/practice | cafb841bd57f74f8fc3690a7f7830e6ca9fda916 | [
"MIT"
] | null | null | null | Linked Lists/Remove Duplicates From Sorted List.cpp | 1aman1/practice | cafb841bd57f74f8fc3690a7f7830e6ca9fda916 | [
"MIT"
] | null | null | null | ListNode* Solution::deleteDuplicates(ListNode* A) {
ListNode* head = A;
while(A -> next ) {
if(A -> val == A -> next -> val) {
ListNode* tmp = A -> next;
while(tmp -> val == A -> val && tmp -> next != NULL) {
tmp = tmp -> next;
}
// if th... | 28.608696 | 75 | 0.411854 | 1aman1 |
e3aa6408ac07cf52f9e388b2ae1974b28a9329e8 | 6,719 | cpp | C++ | codemp/botlib/l_libvar.cpp | xScooper/Makermod | ccf9e10f441503d7b12094168c542a3696ceb314 | [
"MIT"
] | 11 | 2015-09-27T22:53:26.000Z | 2021-12-25T05:04:12.000Z | codemp/botlib/l_libvar.cpp | xScooper/Makermod | ccf9e10f441503d7b12094168c542a3696ceb314 | [
"MIT"
] | 1 | 2016-02-14T14:28:39.000Z | 2017-01-11T13:03:39.000Z | codemp/botlib/l_libvar.cpp | xScooper/Makermod | ccf9e10f441503d7b12094168c542a3696ceb314 | [
"MIT"
] | 11 | 2015-10-19T15:37:24.000Z | 2022-02-07T05:00:20.000Z |
/*****************************************************************************
* name: l_libvar.c
*
* desc: bot library variables
*
* $Archive: /MissionPack/code/botlib/l_libvar.c $
* $Author: Zaphod $
* $Revision: 2 $
* $Modtime: 11/21/00 11:33a $
* $Date: 11/21/00 11:49a $
*
***************************... | 24.169065 | 79 | 0.415389 | xScooper |
e3ae96ac548b4045c500a6a83088220ccb9456f2 | 2,066 | hpp | C++ | include/graphics/Sprite.hpp | Hello56721/wars | d8fb1b88fbb8e863e95d17a2ff96cd5dc197f026 | [
"MIT"
] | 1 | 2021-09-29T14:33:37.000Z | 2021-09-29T14:33:37.000Z | include/graphics/Sprite.hpp | Hello56721/wars | d8fb1b88fbb8e863e95d17a2ff96cd5dc197f026 | [
"MIT"
] | null | null | null | include/graphics/Sprite.hpp | Hello56721/wars | d8fb1b88fbb8e863e95d17a2ff96cd5dc197f026 | [
"MIT"
] | null | null | null | #ifndef D1B01983_88B3_4F44_851C_894D2F00BFF7
#define D1B01983_88B3_4F44_851C_894D2F00BFF7
#include <graphics/Vertex.hpp>
#include <pch.hpp>
namespace wars::graphics
{
// A enumeration that represents which direction a sprite is facing.
enum class SpriteDirection
{
LEFT,
RIGHT
};
... | 25.195122 | 76 | 0.568732 | Hello56721 |
e3b0357eb1315e508a151a5c1bbe24b264ca67a8 | 83,807 | cpp | C++ | src/asm_opcode_manager.cpp | Roxxorfreak/HEdit | 5d7e63729b832727c8ff62a4e4e73e1af9c57bfb | [
"MIT"
] | 6 | 2020-06-06T09:49:37.000Z | 2022-02-18T04:14:40.000Z | src/asm_opcode_manager.cpp | Roxxorfreak/HEdit | 5d7e63729b832727c8ff62a4e4e73e1af9c57bfb | [
"MIT"
] | null | null | null | src/asm_opcode_manager.cpp | Roxxorfreak/HEdit | 5d7e63729b832727c8ff62a4e4e73e1af9c57bfb | [
"MIT"
] | null | null | null | // Copyright (c) 2021 Roxxorfreak
#include "headers.hpp"
/**
* Loads all opcodes.
*/
TAsmOpcodeManager::TAsmOpcodeManager()
{
// Load Intel Opcodes
this->LoadIntelOpcodes();
}
/**
* Loads all known opcodes.
*/
void TAsmOpcodeManager::LoadIntelOpcodes()
{
// Prepare vector
this->o... | 94.271091 | 203 | 0.657236 | Roxxorfreak |
e3b341efe47ef715d854ba7edf9c0850b0bc79da | 910 | cpp | C++ | src/zisa/io/tri_plot.cpp | 1uc/ZisaFVM | 75fcedb3bece66499e011228a39d8a364b50fd74 | [
"MIT"
] | null | null | null | src/zisa/io/tri_plot.cpp | 1uc/ZisaFVM | 75fcedb3bece66499e011228a39d8a364b50fd74 | [
"MIT"
] | null | null | null | src/zisa/io/tri_plot.cpp | 1uc/ZisaFVM | 75fcedb3bece66499e011228a39d8a364b50fd74 | [
"MIT"
] | 1 | 2021-08-24T11:52:51.000Z | 2021-08-24T11:52:51.000Z | // SPDX-License-Identifier: MIT
// Copyright (c) 2021 ETH Zurich, Luc Grosheintz-Laval
#include <zisa/io/tri_plot.hpp>
#if ZISA_HAS_OPENGL != 0
#include <zisa/opengl/window.hpp>
#endif
namespace zisa {
TriPlot::TriPlot(const array<XYZ, 1> &vertices,
const array<int_t, 2> &vertex_indices,
... | 23.333333 | 66 | 0.694505 | 1uc |
e3c9bc782f5813c3f15b57974224537ea84b83e3 | 632 | cpp | C++ | 1000/20/1029a.cpp | actium/cf | d7be128c3a9adb014a231a399f1c5f19e1ab2a38 | [
"Unlicense"
] | 1 | 2020-07-03T15:55:52.000Z | 2020-07-03T15:55:52.000Z | 1000/20/1029a.cpp | actium/cf | d7be128c3a9adb014a231a399f1c5f19e1ab2a38 | [
"Unlicense"
] | null | null | null | 1000/20/1029a.cpp | actium/cf | d7be128c3a9adb014a231a399f1c5f19e1ab2a38 | [
"Unlicense"
] | 3 | 2020-10-01T14:55:28.000Z | 2021-07-11T11:33:58.000Z | #include <iostream>
#include <string>
void answer(const std::string& v)
{
std::cout << v << '\n';
}
void solve(const std::string& t, unsigned k)
{
std::string s;
for (size_t i = 0; k > 0; --k) {
do {
i = s.find(t[0], i+1);
} while (i != std::string::npos && s.substr(i) != t.sub... | 15.047619 | 87 | 0.457278 | actium |
e3d1034c7f9b2719e22ce1ddc80c96ad0c895774 | 2,518 | hpp | C++ | include/codegen/include/NUnit/Framework/ParallelScope.hpp | Futuremappermydud/Naluluna-Modifier-Quest | bfda34370764b275d90324b3879f1a429a10a873 | [
"MIT"
] | 1 | 2021-11-12T09:29:31.000Z | 2021-11-12T09:29:31.000Z | include/codegen/include/NUnit/Framework/ParallelScope.hpp | Futuremappermydud/Naluluna-Modifier-Quest | bfda34370764b275d90324b3879f1a429a10a873 | [
"MIT"
] | null | null | null | include/codegen/include/NUnit/Framework/ParallelScope.hpp | Futuremappermydud/Naluluna-Modifier-Quest | bfda34370764b275d90324b3879f1a429a10a873 | [
"MIT"
] | 2 | 2021-10-03T02:14:20.000Z | 2021-11-12T09:29:36.000Z | // Autogenerated from CppHeaderCreator on 7/27/2020 3:09:57 PM
// Created by Sc2ad
// =========================================================================
#pragma once
#pragma pack(push, 8)
// Begin includes
// Including type: System.Enum
#include "System/Enum.hpp"
#include "utils/il2cpp-utils.hpp"
// Completed in... | 49.372549 | 92 | 0.733916 | Futuremappermydud |
e3d292c062aedefdee962693097377a865e3598f | 6,298 | cpp | C++ | src/gpu/gl/GrGLProgramDesc.cpp | lsalzman/moz-skia | e8acd45f8ab38780df2e99877acb1e0b5846ab2c | [
"Apache-2.0"
] | 7 | 2016-01-12T23:32:32.000Z | 2021-12-03T11:21:26.000Z | src/gpu/gl/GrGLProgramDesc.cpp | lsalzman/moz-skia | e8acd45f8ab38780df2e99877acb1e0b5846ab2c | [
"Apache-2.0"
] | null | null | null | src/gpu/gl/GrGLProgramDesc.cpp | lsalzman/moz-skia | e8acd45f8ab38780df2e99877acb1e0b5846ab2c | [
"Apache-2.0"
] | 6 | 2015-12-09T14:00:19.000Z | 2021-12-06T03:08:43.000Z | /*
* Copyright 2013 Google Inc.
*
* Use of this source code is governed by a BSD-style license that can be
* found in the LICENSE file.
*/
#include "GrGLProgramDesc.h"
#include "GrProcessor.h"
#include "GrGLGpu.h"
#include "GrPipeline.h"
#include "SkChecksum.h"
#include "glsl/GrGLSLFragmentProcessor.h"
#include "... | 38.638037 | 100 | 0.637504 | lsalzman |
e3d9c1720c3a60dadd1bcc4a1765ecbdc3e807c4 | 421 | cpp | C++ | src/AlphaBetaAction.cpp | songchaow/starcrat2-ai | ac6fbdb0e3d7839a76addea4e6aa50a4545841f3 | [
"MIT"
] | 3 | 2020-12-19T01:00:33.000Z | 2021-12-01T01:13:21.000Z | src/AlphaBetaAction.cpp | songchaow/starcrat2-ai | ac6fbdb0e3d7839a76addea4e6aa50a4545841f3 | [
"MIT"
] | null | null | null | src/AlphaBetaAction.cpp | songchaow/starcrat2-ai | ac6fbdb0e3d7839a76addea4e6aa50a4545841f3 | [
"MIT"
] | 2 | 2021-02-22T18:50:38.000Z | 2022-03-21T17:37:24.000Z | #include "AlphaBetaAction.h"
#include "AlphaBetaUnit.h"
AlphaBetaAction::AlphaBetaAction() { }
AlphaBetaAction::AlphaBetaAction(std::shared_ptr<AlphaBetaUnit> punit, std::shared_ptr<AlphaBetaUnit> ptarget, sc2::Point2D pposition, float pdistance, AlphaBetaActionType ptype, float ptime) {
unit = punit;
target ... | 32.384615 | 193 | 0.733967 | songchaow |
e3d9d7d16f9154e5f6c77390e8155a8eb5bb2614 | 7,136 | cc | C++ | samples/framework/internal/shooter.cc | nstokes2/ozz-animation | 0b9a1c90398dbc8dc11394fbc93720159db19cc9 | [
"Zlib"
] | null | null | null | samples/framework/internal/shooter.cc | nstokes2/ozz-animation | 0b9a1c90398dbc8dc11394fbc93720159db19cc9 | [
"Zlib"
] | null | null | null | samples/framework/internal/shooter.cc | nstokes2/ozz-animation | 0b9a1c90398dbc8dc11394fbc93720159db19cc9 | [
"Zlib"
] | null | null | null | //============================================================================//
// //
// ozz-animation, 3d skeletal animation libraries and tools. //
// https://code.google.com/p/ozz-animation/ ... | 33.037037 | 82 | 0.515835 | nstokes2 |
e3e14eef48556bb2b1e0448768e7ee2f68f08bdc | 886 | cpp | C++ | Codeforces 520B.cpp | Jvillegasd/Codeforces | ffdd2d5db1dabc7ff76f8f92270c79233a77b933 | [
"MIT"
] | null | null | null | Codeforces 520B.cpp | Jvillegasd/Codeforces | ffdd2d5db1dabc7ff76f8f92270c79233a77b933 | [
"MIT"
] | null | null | null | Codeforces 520B.cpp | Jvillegasd/Codeforces | ffdd2d5db1dabc7ff76f8f92270c79233a77b933 | [
"MIT"
] | null | null | null | #include <stdio.h>
#include <queue>
#include <string.h>
using namespace std;
int BFS(int n, int m){
queue<int> cola;
int clicks[10010];
memset(clicks, -1, sizeof(clicks));
clicks[n] = 0;
cola.push(n);
while(!cola.empty()){
int number = cola.front();
cola.pop();
if(numbe... | 23.945946 | 64 | 0.460497 | Jvillegasd |
e3e6ec7f1eb45bb569475aadce58051ab19130b3 | 7,814 | cpp | C++ | demo/Linux/src/ibus_fun_engine.cpp | zhangfuwen/alibabacloud-nls-cpp-sdk | 8c059f5a7635b6df5d54bf4e41a0f62028adc894 | [
"Apache-2.0"
] | null | null | null | demo/Linux/src/ibus_fun_engine.cpp | zhangfuwen/alibabacloud-nls-cpp-sdk | 8c059f5a7635b6df5d54bf4e41a0f62028adc894 | [
"Apache-2.0"
] | null | null | null | demo/Linux/src/ibus_fun_engine.cpp | zhangfuwen/alibabacloud-nls-cpp-sdk | 8c059f5a7635b6df5d54bf4e41a0f62028adc894 | [
"Apache-2.0"
] | null | null | null | //
// Created by zhangfuwen on 2022/1/27.
//
#include "ibus_fun_engine.h"
#include "Engine.h"
#include "common_log.h"
// ------------------- define type ---------------------
#define IBUS_FUN_ENGINE(obj) \
(G_TYPE_CHECK_INSTANCE_CAST ((obj), IBUS_TYPE_FUN_ENGINE, IBusFunEngine))
#define IBUS_FUN_ENGIN... | 39.464646 | 96 | 0.596621 | zhangfuwen |
e3ec8d185452dd74f81bac431b955b88db199f9d | 766 | hpp | C++ | source/lightspace/public/ray.hpp | gitbetter/Lightspace | b00a29e2aac64cfac87ca30d2d053559d84289df | [
"MIT"
] | null | null | null | source/lightspace/public/ray.hpp | gitbetter/Lightspace | b00a29e2aac64cfac87ca30d2d053559d84289df | [
"MIT"
] | null | null | null | source/lightspace/public/ray.hpp | gitbetter/Lightspace | b00a29e2aac64cfac87ca30d2d053559d84289df | [
"MIT"
] | null | null | null | #pragma once
#include "tensor.hpp"
#include "matrix.hpp"
namespace ls {
class ray
{
public:
ray( const f_point& o, const f_vector& d ) :
origin_( o ), direction_( d )
{ }
const f_point position( fpnum t ) const noexcept
{
return origin_ + direction... | 18.682927 | 77 | 0.523499 | gitbetter |
e3efe2b24551ec56a17824b93dfeaaaccd3760fb | 1,556 | cpp | C++ | LeetCodeCPP/322. Coin Change/main.cpp | 18600130137/leetcode | fd2dc72c0b85da50269732f0fcf91326c4787d3a | [
"Apache-2.0"
] | 1 | 2019-03-29T03:33:56.000Z | 2019-03-29T03:33:56.000Z | LeetCodeCPP/322. Coin Change/main.cpp | 18600130137/leetcode | fd2dc72c0b85da50269732f0fcf91326c4787d3a | [
"Apache-2.0"
] | null | null | null | LeetCodeCPP/322. Coin Change/main.cpp | 18600130137/leetcode | fd2dc72c0b85da50269732f0fcf91326c4787d3a | [
"Apache-2.0"
] | null | null | null | //
// main.cpp
// 322. Coin Change
//
// Created by admin on 2019/7/30.
// Copyright © 2019年 liu. All rights reserved.
//
#include <iostream>
#include <vector>
using namespace std;
class Solution {
private:
int helper(vector<int>& coins, int amount,vector<int>& rem){
if(amount<0){
return ... | 23.223881 | 65 | 0.48329 | 18600130137 |
e3f4b2ab28cfde6fe6c8ff056502a5384a788eac | 1,186 | cpp | C++ | .LHP/.Lop12/.PreHSG/.T.Hung/D4/COLOR/color_br.cpp | sxweetlollipop2912/MaCode | 661d77a2096e4d772fda2b6a7f80c84113b2cde9 | [
"MIT"
] | null | null | null | .LHP/.Lop12/.PreHSG/.T.Hung/D4/COLOR/color_br.cpp | sxweetlollipop2912/MaCode | 661d77a2096e4d772fda2b6a7f80c84113b2cde9 | [
"MIT"
] | null | null | null | .LHP/.Lop12/.PreHSG/.T.Hung/D4/COLOR/color_br.cpp | sxweetlollipop2912/MaCode | 661d77a2096e4d772fda2b6a7f80c84113b2cde9 | [
"MIT"
] | null | null | null | #include <iostream>
#include <algorithm>
#include <cstdio>
#include <string>
#define maxN 100002
#define maxC 28
#define C 26
#define num(c) ((c) - 'a')
#define cal(cnt, len) ((cnt) / (maxr)(len))
#define equal(x, y) (std::abs((x) - (y)) < eps)
#define greater(x, y) ((x) - eps > (y))
typedef long maxn;
typedef double... | 20.448276 | 87 | 0.491568 | sxweetlollipop2912 |
e3fb40129a0d8b1420571c6faa879430b1d75407 | 9,570 | hpp | C++ | src/IO/ExodusIIMeshReader.hpp | franjgonzalez/Quinoa | 411eb8815e92618c563881b784e287e2dd916f89 | [
"RSA-MD"
] | null | null | null | src/IO/ExodusIIMeshReader.hpp | franjgonzalez/Quinoa | 411eb8815e92618c563881b784e287e2dd916f89 | [
"RSA-MD"
] | null | null | null | src/IO/ExodusIIMeshReader.hpp | franjgonzalez/Quinoa | 411eb8815e92618c563881b784e287e2dd916f89 | [
"RSA-MD"
] | null | null | null | // *****************************************************************************
/*!
\file src/IO/ExodusIIMeshReader.hpp
\copyright 2012-2015 J. Bakosi,
2016-2018 Los Alamos National Security, LLC.,
2019 Triad National Security, LLC.
All rights reserved. See the LICENSE f... | 37.529412 | 80 | 0.607732 | franjgonzalez |
54055777a8e77b74f0d933bb179849737d7d9c72 | 4,811 | cc | C++ | src/vdmx.cc | MicroJoe/ots | 56fa835f0eacc313323144aca4a61d8085fe7c20 | [
"BSD-3-Clause"
] | 2,151 | 2020-04-18T07:31:17.000Z | 2022-03-31T08:39:18.000Z | src/vdmx.cc | MicroJoe/ots | 56fa835f0eacc313323144aca4a61d8085fe7c20 | [
"BSD-3-Clause"
] | 395 | 2020-04-18T08:22:18.000Z | 2021-12-08T13:04:49.000Z | src/vdmx.cc | MicroJoe/ots | 56fa835f0eacc313323144aca4a61d8085fe7c20 | [
"BSD-3-Clause"
] | 338 | 2020-04-18T08:03:10.000Z | 2022-03-29T12:33:22.000Z | // Copyright (c) 2009-2017 The OTS Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "vdmx.h"
// VDMX - Vertical Device Metrics
// http://www.microsoft.com/typography/otspec/vdmx.htm
namespace ots {
bool OpenTypeVDMX::Parse... | 30.839744 | 79 | 0.60133 | MicroJoe |
54125730e7eb9a6858c1fec224fc2e47962913bc | 762 | cpp | C++ | timus/volume-07/flat_spots.cpp | Rkhoiwal/Competitive-prog-Archive | 18a95a8b2b9ca1a28d6fe939c1db5450d541ddc9 | [
"MIT"
] | 1 | 2020-07-16T01:46:38.000Z | 2020-07-16T01:46:38.000Z | timus/volume-07/flat_spots.cpp | Rkhoiwal/Competitive-prog-Archive | 18a95a8b2b9ca1a28d6fe939c1db5450d541ddc9 | [
"MIT"
] | null | null | null | timus/volume-07/flat_spots.cpp | Rkhoiwal/Competitive-prog-Archive | 18a95a8b2b9ca1a28d6fe939c1db5450d541ddc9 | [
"MIT"
] | 1 | 2020-05-27T14:30:43.000Z | 2020-05-27T14:30:43.000Z | #include <iostream>
#include <vector>
using namespace std;
constexpr unsigned int min_diameter {600};
constexpr unsigned int max_diameter {700};
constexpr unsigned int diameters {101};
inline void use_io_optimizations()
{
ios_base::sync_with_stdio(false);
cin.tie(nullptr);
}
int main()
{
use_io_optim... | 17.318182 | 52 | 0.632546 | Rkhoiwal |
541331cfe548ccbcbbb5ef8dd08a44583760d348 | 277 | cpp | C++ | src/cpu/insts/Lahf.cpp | ammubhave/emu | ff9501719f3cc53207a8931d85c19d24c86dccdc | [
"MIT"
] | null | null | null | src/cpu/insts/Lahf.cpp | ammubhave/emu | ff9501719f3cc53207a8931d85c19d24c86dccdc | [
"MIT"
] | null | null | null | src/cpu/insts/Lahf.cpp | ammubhave/emu | ff9501719f3cc53207a8931d85c19d24c86dccdc | [
"MIT"
] | null | null | null | #include "gen/Lahf.h"
#include "cpu/Cpu.h"
#include "cpu/insts/Util.h"
namespace emu::cpu::insts {
template <typename Op1>
void Lahf<Op1>::execute(Cpu& cpu) {
op1_.w(static_cast<uint8_t>(cpu.regs_.flags.value));
}
} // namespace emu::cpu::insts
#include "gen/Lahf.cpp"
| 17.3125 | 54 | 0.685921 | ammubhave |
54155a256508f73e5cb30a4e541df5abb167a72b | 1,700 | hpp | C++ | tests/small_object_tests.hpp | zie87/neoloki-lib | ffa22058d872dd60f4d99bebe4c2a8aeec087424 | [
"MIT"
] | null | null | null | tests/small_object_tests.hpp | zie87/neoloki-lib | ffa22058d872dd60f4d99bebe4c2a8aeec087424 | [
"MIT"
] | null | null | null | tests/small_object_tests.hpp | zie87/neoloki-lib | ffa22058d872dd60f4d99bebe4c2a8aeec087424 | [
"MIT"
] | null | null | null | #ifndef NEOLOKI_SMALLOBJECTTESTS_HPP
#define NEOLOKI_SMALLOBJECTTESTS_HPP
#include <loki/small_object.hpp>
#include "unit_test.hpp"
namespace loki {
struct small_object_test : test {
small_object_test() : test("small_object.hpp") {}
virtual void execute(test_result& results) override {
{
... | 24.285714 | 85 | 0.56 | zie87 |
542058b7e8ca1e71a65c19c994aabb0ca062a8ed | 2,416 | cpp | C++ | minic/src/main.cpp | waldnercharles/MiniC | a8a86d3174bc54acd24fc1df0bdba6e9eac0cc5d | [
"Unlicense"
] | null | null | null | minic/src/main.cpp | waldnercharles/MiniC | a8a86d3174bc54acd24fc1df0bdba6e9eac0cc5d | [
"Unlicense"
] | null | null | null | minic/src/main.cpp | waldnercharles/MiniC | a8a86d3174bc54acd24fc1df0bdba6e9eac0cc5d | [
"Unlicense"
] | null | null | null | #include "minic/allocator_default.h"
#include "minic/array.h"
#include "minic/handle.h"
#include "minic/int.h"
#include "minic/io.h"
#include "minic/memory.h"
#include "minic/platform.h"
#include "minic/window.h"
#include "win32/wingdi.h"
//#include <Windows.h>
#include <gl/GL.h>
//#include "minic/asset.h"
//#include... | 24.653061 | 73 | 0.644454 | waldnercharles |
542ac10f2f95ddc8f0c64620468b964b96c4dd85 | 1,961 | cpp | C++ | src/base/ossimEvent.cpp | vladislav-horbatiuk/ossim | 82417ad868fac022672335e1684bdd91d662c18c | [
"MIT"
] | 251 | 2015-10-20T09:08:11.000Z | 2022-03-22T18:16:38.000Z | src/base/ossimEvent.cpp | IvanLJF/ossim | 2e0143f682b9884a09ff2598ef8737f29e44fbdf | [
"MIT"
] | 73 | 2015-11-02T17:12:36.000Z | 2021-11-15T17:41:47.000Z | src/base/ossimEvent.cpp | IvanLJF/ossim | 2e0143f682b9884a09ff2598ef8737f29e44fbdf | [
"MIT"
] | 146 | 2015-10-15T16:00:15.000Z | 2022-03-22T12:37:14.000Z | //*******************************************************************
//
// License: See top level LICENSE.txt file.
//
// Author: Garrett Potts (gpotts@imagelinks)
// Description: A brief description of the contents of the file.
//
//
//*************************************************************************
// $Id... | 17.990826 | 75 | 0.700153 | vladislav-horbatiuk |
f9afa788553e58d342b0a4dbeb2c4823be1369ef | 3,593 | cpp | C++ | eip/src/v2/model/QuotaShowResp.cpp | yangzhaofeng/huaweicloud-sdk-cpp-v3 | 4f3caac5ba9a9b75b4e5fd61683d1c4d57ec1c23 | [
"Apache-2.0"
] | 5 | 2021-03-03T08:23:43.000Z | 2022-02-16T02:16:39.000Z | eip/src/v2/model/QuotaShowResp.cpp | yangzhaofeng/huaweicloud-sdk-cpp-v3 | 4f3caac5ba9a9b75b4e5fd61683d1c4d57ec1c23 | [
"Apache-2.0"
] | null | null | null | eip/src/v2/model/QuotaShowResp.cpp | yangzhaofeng/huaweicloud-sdk-cpp-v3 | 4f3caac5ba9a9b75b4e5fd61683d1c4d57ec1c23 | [
"Apache-2.0"
] | 7 | 2021-02-26T13:53:35.000Z | 2022-03-18T02:36:43.000Z |
#include "huaweicloud/eip/v2/model/QuotaShowResp.h"
namespace HuaweiCloud {
namespace Sdk {
namespace Eip {
namespace V2 {
namespace Model {
QuotaShowResp::QuotaShowResp()
{
type_ = "";
typeIsSet_ = false;
used_ = 0;
usedIsSet_ = false;
quota_ = 0;
quotaIsSet_ = false;
min_ = 0;
m... | 19.213904 | 96 | 0.621765 | yangzhaofeng |
f9b107224c05b7024c51678df256bb2ed99ea5d6 | 1,225 | hpp | C++ | include/config.hpp | theKlanc/Z3 | 97c28f31483d1d5c8c7d1aa61155b256b3d4094a | [
"MIT"
] | 4 | 2020-08-09T20:34:28.000Z | 2021-07-22T23:30:40.000Z | include/config.hpp | theKlanc/Z3 | 97c28f31483d1d5c8c7d1aa61155b256b3d4094a | [
"MIT"
] | 5 | 2020-02-18T23:19:14.000Z | 2020-02-18T23:26:24.000Z | include/config.hpp | theKlanc/Z3 | 97c28f31483d1d5c8c7d1aa61155b256b3d4094a | [
"MIT"
] | null | null | null | #pragma once
#include <string>
namespace config {
constexpr int chunksContainerSize
#ifdef __SWITCH__
= 10;
#elif __EMSCRIPTEN__
= 10;
#else
= 14;
#endif
extern bool fogEnabled;
constexpr int fogLayers = 20;
extern bool render;
constexpr int chunk... | 25 | 50 | 0.698776 | theKlanc |
f9bcc0f96e1cae1b847d06068b7b1f9d22b1b80f | 13,257 | cpp | C++ | tests/lab10test/SchedulerTest.cpp | Adrjanjan/JiMP-Exercises | 0c5de5878bcf0ede27fedcdf3cebbe081679e180 | [
"MIT"
] | null | null | null | tests/lab10test/SchedulerTest.cpp | Adrjanjan/JiMP-Exercises | 0c5de5878bcf0ede27fedcdf3cebbe081679e180 | [
"MIT"
] | null | null | null | tests/lab10test/SchedulerTest.cpp | Adrjanjan/JiMP-Exercises | 0c5de5878bcf0ede27fedcdf3cebbe081679e180 | [
"MIT"
] | null | null | null | //
// Created by mwypych on 11.05.17.
//
#include <vector>
#include <algorithm>
#include <numeric>
#include <string>
#include <memory>
#include <set>
#include <vector>
#include <utility>
#include <map>
#include <ostream>
#include <gtest/gtest.h>
#include <MemLeakTest.h>
#include <StringUtility.h>
#include <Scheduler.h... | 38.537791 | 119 | 0.675341 | Adrjanjan |
f9c01898872381e8a8d35385e0e1b5a733f5231e | 673 | cpp | C++ | src/sinks/console.cpp | ihor-drachuk/alog | d2601e8523612f5e6890dad5a7fbcc5424bd693b | [
"MIT"
] | null | null | null | src/sinks/console.cpp | ihor-drachuk/alog | d2601e8523612f5e6890dad5a7fbcc5424bd693b | [
"MIT"
] | null | null | null | src/sinks/console.cpp | ihor-drachuk/alog | d2601e8523612f5e6890dad5a7fbcc5424bd693b | [
"MIT"
] | null | null | null | #include <alog/sinks/console.h>
namespace ALog {
namespace Sinks {
Console::Console(Console::Stream stream)
{
switch (stream) {
case Stream::StdOut:
m_handle = stdout;
break;
case Stream::StdErr:
m_handle = stderr;
break;
}
}
void Console::writ... | 19.794118 | 71 | 0.589896 | ihor-drachuk |
f9c8beeb71a6f399b28fb502a6794749aa21bb7b | 285 | cpp | C++ | examples/mod_full_paren_if_bool/true_01.unc.cpp | beardog-ukr/uncrustify-config-examples | 23308192b377107cf287bdb073ae7eccbbf06383 | [
"Unlicense"
] | 1 | 2021-06-23T00:12:23.000Z | 2021-06-23T00:12:23.000Z | examples/mod_full_paren_if_bool/true_01.unc.cpp | beardog-ukr/uncrustify-config-examples | 23308192b377107cf287bdb073ae7eccbbf06383 | [
"Unlicense"
] | null | null | null | examples/mod_full_paren_if_bool/true_01.unc.cpp | beardog-ukr/uncrustify-config-examples | 23308192b377107cf287bdb073ae7eccbbf06383 | [
"Unlicense"
] | null | null | null | #include <iostream>
bool isOdd(int x) {
return true;
}
int main()
{
int x = 10;
int y = 20;
if (isOdd(x) && (x<y)) {
std::cout << "x is odd and less than " << y << '\n';
}
while(isOdd(x) && x>0) {
x=x-3;
}
std::cout << "transformed x is " << x << '\n';
return 0;
}
| 11.4 | 54 | 0.487719 | beardog-ukr |
f9cb180d9081072c521ce98ad1df2b1a994a23ee | 3,932 | cpp | C++ | drivers/tftespi/lvdrv-tftespi.cpp | yhfudev/lv_platformio | 45c9c2b1cdb14dac07fe59dc2993d6e33f07bc1d | [
"MIT"
] | null | null | null | drivers/tftespi/lvdrv-tftespi.cpp | yhfudev/lv_platformio | 45c9c2b1cdb14dac07fe59dc2993d6e33f07bc1d | [
"MIT"
] | null | null | null | drivers/tftespi/lvdrv-tftespi.cpp | yhfudev/lv_platformio | 45c9c2b1cdb14dac07fe59dc2993d6e33f07bc1d | [
"MIT"
] | null | null | null | /**
* \file lvdrv-tftespi.cpp
* \brief TFT eSPI driver for LittlevGL
* \author Yunhui Fu (yhfudev@gmail.com)
* \version 1.0
* \date 2020-02-03
* \copyright GPL/BSD
*/
//#include <SPI.h>
#include <TFT_eSPI.h> // Hardware-specific library
#include "lvgl.h"
#include "lvdrv-tftespi.h"
#include "setuprotar... | 30.96063 | 112 | 0.618006 | yhfudev |
f9cd58d2bafeb623c87a8ec98c6f025796b3587d | 1,251 | cpp | C++ | src/engines/AliCloud.cpp | jimpark/libvault | 35657160c45874cd38bf4b6f0a204c7c26a4dd38 | [
"MIT"
] | 24 | 2019-01-28T19:37:38.000Z | 2022-03-10T01:09:53.000Z | src/engines/AliCloud.cpp | jimpark/libvault | 35657160c45874cd38bf4b6f0a204c7c26a4dd38 | [
"MIT"
] | 59 | 2019-03-27T22:34:21.000Z | 2022-03-25T23:43:57.000Z | src/engines/AliCloud.cpp | jimpark/libvault | 35657160c45874cd38bf4b6f0a204c7c26a4dd38 | [
"MIT"
] | 20 | 2019-06-13T11:58:19.000Z | 2022-02-17T23:38:28.000Z | #include "VaultClient.h"
std::optional<std::string> Vault::AliCloud::Secrets::readConfig() {
return HttpConsumer::get(client_, getUrl(Path{"config"}));
}
std::optional<std::string> Vault::AliCloud::Secrets::createConfig(const Parameters ¶meters) {
return HttpConsumer::post(client_, getUrl(Path{"config"}), par... | 36.794118 | 113 | 0.721823 | jimpark |
f9d440a94634bbbcf985a529859ba44bb444a07a | 4,171 | hpp | C++ | device/rocm/rocdefs.hpp | zhaozhangjian/ROCclr | 5cefcaf62893fcd86c8feed6bb1ebb84850fcd2f | [
"MIT"
] | 1 | 2020-12-09T10:20:35.000Z | 2020-12-09T10:20:35.000Z | device/rocm/rocdefs.hpp | Acidburn0zzz/ROCclr | 5cefcaf62893fcd86c8feed6bb1ebb84850fcd2f | [
"MIT"
] | null | null | null | device/rocm/rocdefs.hpp | Acidburn0zzz/ROCclr | 5cefcaf62893fcd86c8feed6bb1ebb84850fcd2f | [
"MIT"
] | null | null | null | /* Copyright (c) 2008-present Advanced Micro Devices, Inc.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, me... | 52.797468 | 88 | 0.608487 | zhaozhangjian |
f9d66c874afeadbc25bb662bc65d9940126ec8d7 | 1,304 | hpp | C++ | 3rdParty/detail/reverse_bits.hpp | zero9178/cld | 2899ade8045074c5ee939253d2d7f8067c46e72d | [
"MIT"
] | 14 | 2020-10-16T08:29:32.000Z | 2021-12-21T10:37:05.000Z | 3rdParty/detail/reverse_bits.hpp | zero9178/cld | 2899ade8045074c5ee939253d2d7f8067c46e72d | [
"MIT"
] | null | null | null | 3rdParty/detail/reverse_bits.hpp | zero9178/cld | 2899ade8045074c5ee939253d2d7f8067c46e72d | [
"MIT"
] | null | null | null | // BITSET2
//
// Copyright Claas Bontus
//
// Use, modification and distribution is subject to the
// Boost Software License, Version 1.0. (See accompanying
// file LICENSE.txt or copy at
// http://www.boost.org/LICENSE_1_0.txt)
//
// Project home: https://github.com/ClaasBontus/bitset2
//
#ifndef BITSET2_REVERSE... | 23.285714 | 114 | 0.642638 | zero9178 |
f9da3a039d38875c10b24e894eb656916670991a | 897 | hh | C++ | Bum9a/Bum9examples2/Hyperhelp/Hhhelp.hh | binaryfoundry/BLITZCD | 1972dd58ecaa743631db44676d68586a0c53e8f9 | [
"Unlicense"
] | 1 | 2019-05-27T15:33:35.000Z | 2019-05-27T15:33:35.000Z | Bum9a/Bum9examples2/Hyperhelp/Hhhelp.hh | mechanicsfoundry/BLITZCD | 1972dd58ecaa743631db44676d68586a0c53e8f9 | [
"Unlicense"
] | null | null | null | Bum9a/Bum9examples2/Hyperhelp/Hhhelp.hh | mechanicsfoundry/BLITZCD | 1972dd58ecaa743631db44676d68586a0c53e8f9 | [
"Unlicense"
] | 1 | 2021-12-27T17:15:14.000Z | 2021-12-27T17:15:14.000Z | [f fonts:topaz.font|11][c][b][l hhwelcome.snd|snd]Welcome[l]
to HyperHelp version 2.0![b][c][f fonts:topaz.font|8][t Welcome to HyperHelp 2][h]
[i]Nothing contained in this help-file can be considered the truth, the whole
truth and anything but the truth. I might have forgotten something, or made a
typing mistake, or e... | 47.210526 | 82 | 0.732441 | binaryfoundry |
f9e1060193d627fe74811175119f57a395462f10 | 29,150 | cc | C++ | wrappers/8.1.1/vtkOpenGLPolyDataMapperWrap.cc | axkibe/node-vtk | 900ad7b5500f672519da5aa24c99aa5a96466ef3 | [
"BSD-3-Clause"
] | 6 | 2016-02-03T12:48:36.000Z | 2020-09-16T15:07:51.000Z | wrappers/8.1.1/vtkOpenGLPolyDataMapperWrap.cc | axkibe/node-vtk | 900ad7b5500f672519da5aa24c99aa5a96466ef3 | [
"BSD-3-Clause"
] | 4 | 2016-02-13T01:30:43.000Z | 2020-03-30T16:59:32.000Z | wrappers/8.1.1/vtkOpenGLPolyDataMapperWrap.cc | axkibe/node-vtk | 900ad7b5500f672519da5aa24c99aa5a96466ef3 | [
"BSD-3-Clause"
] | null | null | null | /* this file has been autogenerated by vtkNodeJsWrap */
/* editing this might proof futile */
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include <nan.h>
#include "vtkPolyDataMapperWrap.h"
#include "vtkOpenGLPolyDataMapperWrap.h"
#include "vtkObjectBaseWrap.h"
#include "vtkRendererWrap.h"
#include "vtkActo... | 35.247884 | 116 | 0.74741 | axkibe |
f9e6354012a826db3c070c90e1d519e1e3610544 | 1,814 | cpp | C++ | A. Hamburgers.cpp | Mahboub99/CodeForces_UVA | c5cfad64d573ef21b67d97e17bd4f14fb01de9fa | [
"MIT"
] | 3 | 2020-01-03T11:38:43.000Z | 2021-03-13T13:34:49.000Z | A. Hamburgers.cpp | Mahboub99/CodeForces_UVA | c5cfad64d573ef21b67d97e17bd4f14fb01de9fa | [
"MIT"
] | null | null | null | A. Hamburgers.cpp | Mahboub99/CodeForces_UVA | c5cfad64d573ef21b67d97e17bd4f14fb01de9fa | [
"MIT"
] | 2 | 2019-10-16T19:52:15.000Z | 2019-10-28T08:52:38.000Z | #include <iostream>
#include <cmath>
#include <string>
#include <string.h>
#include <stdlib.h>
#include <algorithm>
#include <iomanip>
#include <assert.h>
#include <vector>
#include <cstring>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <sstream>
#include <cstdio>
#include <cstdlib>
#inclu... | 24.513514 | 90 | 0.545755 | Mahboub99 |
f9e9b1e9d0be510ff885134dd61c98d98f4318f1 | 4,517 | hpp | C++ | include/BeatmapSaveDataVersion2_6_0AndEarlier/BeatmapSaveDataItem.hpp | RedBrumbler/BeatSaber-Quest-Codegen | 73dda50b5a3e51f10d86b766dcaa24b0c6226e25 | [
"Unlicense"
] | null | null | null | include/BeatmapSaveDataVersion2_6_0AndEarlier/BeatmapSaveDataItem.hpp | RedBrumbler/BeatSaber-Quest-Codegen | 73dda50b5a3e51f10d86b766dcaa24b0c6226e25 | [
"Unlicense"
] | null | null | null | include/BeatmapSaveDataVersion2_6_0AndEarlier/BeatmapSaveDataItem.hpp | RedBrumbler/BeatSaber-Quest-Codegen | 73dda50b5a3e51f10d86b766dcaa24b0c6226e25 | [
"Unlicense"
] | null | null | null | // Autogenerated from CppHeaderCreator
// Created by Sc2ad
// =========================================================================
#pragma once
// Begin includes
#include "beatsaber-hook/shared/utils/typedefs.h"
#include "beatsaber-hook/shared/utils/byref.hpp"
// Including type: System.IComparable`1
#include "Syst... | 60.226667 | 275 | 0.785477 | RedBrumbler |
f9f8903df2446d1dcaea992c8b05845afe865b91 | 2,949 | hpp | C++ | xvm/xvm_interface.hpp | kiven-li/xscrip | ed762811aaf502ee20b5d00083926f7647def57d | [
"MIT"
] | 15 | 2018-11-10T11:30:09.000Z | 2022-02-28T06:00:57.000Z | xvm/xvm_interface.hpp | kiven-li/xscrip | ed762811aaf502ee20b5d00083926f7647def57d | [
"MIT"
] | null | null | null | xvm/xvm_interface.hpp | kiven-li/xscrip | ed762811aaf502ee20b5d00083926f7647def57d | [
"MIT"
] | 10 | 2019-06-19T03:33:53.000Z | 2021-08-20T01:24:42.000Z | #ifndef __XSCRIPT_XVM_INTERFACE_HPP__
#define __XSCRIPT_XVM_INTERFACE_HPP__
#include <string>
using std::string;
#define XS_GLOBAL_FUNC -1// Flags a host API function as being global
enum SCRIPT_LOAD_ERROR_CODE
{
XS_LOAD_OK = 0,
XS_LOAD_ERROR_FILE_IO,
XS_LOAD_ERROR_INVALI... | 37.329114 | 107 | 0.726009 | kiven-li |
f9fa90fa4848eb570c67bee4242c989968b2b76a | 958 | cpp | C++ | list/25 Reverse Nodes in k-Group.cpp | CoderQuinnYoung/leetcode | 6ea15c68124b16824bab9ed2e0e5a40c72eb3db1 | [
"BSD-3-Clause"
] | null | null | null | list/25 Reverse Nodes in k-Group.cpp | CoderQuinnYoung/leetcode | 6ea15c68124b16824bab9ed2e0e5a40c72eb3db1 | [
"BSD-3-Clause"
] | null | null | null | list/25 Reverse Nodes in k-Group.cpp | CoderQuinnYoung/leetcode | 6ea15c68124b16824bab9ed2e0e5a40c72eb3db1 | [
"BSD-3-Clause"
] | null | null | null | //
// 25 Reverse Nodes in k-Group.cpp
// Leetcode
//
// Created by Quinn on 2020/9/15.
// Copyright © 2020 Quinn. All rights reserved.
//
#include "ListNode.h"
using namespace std;
class Solution {
public:
ListNode* reverseKGroup(ListNode* head, int k) {
ListNode *dummy = new ListNode(-1);
dum... | 21.772727 | 52 | 0.385177 | CoderQuinnYoung |
e600dd785d5fe85782139b5706fbac153cdfac80 | 10,190 | cpp | C++ | LEngine/src/BaseShaderClass.cpp | komilll/LEngine | 16ce392d9164abbf2e99fe207089c63337762275 | [
"MIT"
] | 2 | 2020-07-22T14:05:03.000Z | 2021-09-06T19:36:08.000Z | LEngine/src/BaseShaderClass.cpp | komilll/LEngine | 16ce392d9164abbf2e99fe207089c63337762275 | [
"MIT"
] | null | null | null | LEngine/src/BaseShaderClass.cpp | komilll/LEngine | 16ce392d9164abbf2e99fe207089c63337762275 | [
"MIT"
] | 2 | 2019-03-01T02:44:41.000Z | 2020-02-11T18:08:36.000Z | #include "BaseShaderClass.h"
bool BaseShaderClass::Initialize(ID3D11Device* device, HWND hwnd, WCHAR* vsFilename, WCHAR* psFilename, vertexInputType vertexInput)
{
//Initialize through this method because constructor may throw
return InitializeShader(device, hwnd, vsFilename, psFilename, vertexInput);
}
void BaseS... | 31.744548 | 159 | 0.765849 | komilll |
e602f5bf25573c342d550f92daeffb49c9e6ab78 | 2,633 | cc | C++ | Index/Include/Include_IndexUI/index_ui_impl/ui/mapper/mapper.cc | ChronesDev/Index2 | 3910cea02928e0faaa92e2cc4ae76bcdf3939a14 | [
"MIT"
] | 103 | 2021-07-22T21:04:19.000Z | 2021-12-29T20:37:04.000Z | Index/Include/Include_IndexUI/index_ui_impl/ui/mapper/mapper.cc | ChronesDev/Index2 | 3910cea02928e0faaa92e2cc4ae76bcdf3939a14 | [
"MIT"
] | 3 | 2021-07-22T13:47:33.000Z | 2022-03-09T19:41:11.000Z | Index/Include/Include_IndexUI/index_ui_impl/ui/mapper/mapper.cc | ChronesDev/Index2 | 3910cea02928e0faaa92e2cc4ae76bcdf3939a14 | [
"MIT"
] | null | null | null | #pragma once
#include "../ui.cc"
#define INDEX_UI_Declare(name) \
struct name; \
struct name##Mapper
#define INDEX_UI_Decl... | 26.33 | 119 | 0.473984 | ChronesDev |
e60b6dad8e1fd0db7b8e8f47a983faf39eef48a2 | 1,129 | hpp | C++ | imageprovider.hpp | pgulotta/TestBox2D | 048598c107543f03ab419f343bf2e3a3b926af3f | [
"MIT"
] | 1 | 2020-08-23T19:00:43.000Z | 2020-08-23T19:00:43.000Z | imageprovider.hpp | pgulotta/TestBox2D | 048598c107543f03ab419f343bf2e3a3b926af3f | [
"MIT"
] | null | null | null | imageprovider.hpp | pgulotta/TestBox2D | 048598c107543f03ab419f343bf2e3a3b926af3f | [
"MIT"
] | 1 | 2021-06-08T22:50:52.000Z | 2021-06-08T22:50:52.000Z | #pragma once
#include <QQuickImageProvider>
#include <memory>
class QVariant;
class ImageProvider : public QQuickImageProvider
{
public:
ImageProvider( );
QImage requestImage( const QString& id, QSize* size, const QSize& requestedSize ) override;
void setWindowDimenions( int windowWidth, int windowHeight ) ;
... | 20.527273 | 93 | 0.744021 | pgulotta |
e60bb75ce5bc739aea2dae3ef6edcbf47548161c | 1,762 | cpp | C++ | Chess/PieceView.cpp | sharethl/ChineseChess | 9c1d9b87bf9e9a083134376cf902b2d98d008c2d | [
"MIT"
] | null | null | null | Chess/PieceView.cpp | sharethl/ChineseChess | 9c1d9b87bf9e9a083134376cf902b2d98d008c2d | [
"MIT"
] | null | null | null | Chess/PieceView.cpp | sharethl/ChineseChess | 9c1d9b87bf9e9a083134376cf902b2d98d008c2d | [
"MIT"
] | null | null | null | #include "PieceView.h"
#include <QPainter>
#include <QTime>
PieceView::PieceView(QWidget *parent, ChessPiece *piece)
: QWidget(parent)
, _piece(piece)
{
_defaultBrush = piece->player() == Player::Black ? QBrush(QColor(192, 190, 192))
: QBrush(QColor(25... | 21.228916 | 85 | 0.620885 | sharethl |
e61105c0c1b7964bc2f907334464d5c41abf308f | 1,823 | hpp | C++ | test/Asserts.hpp | Gregofi/metrics | a8da292a98b66a36329f1e5c9423ec01d86c07a1 | [
"MIT"
] | null | null | null | test/Asserts.hpp | Gregofi/metrics | a8da292a98b66a36329f1e5c9423ec01d86c07a1 | [
"MIT"
] | 1 | 2022-02-05T09:52:40.000Z | 2022-02-05T09:52:40.000Z | test/Asserts.hpp | Gregofi/metrics | a8da292a98b66a36329f1e5c9423ec01d86c07a1 | [
"MIT"
] | null | null | null | #ifndef METRICS_ASSERTS_HPP
#define METRICS_ASSERTS_HPP
#include <iostream>
#include <cassert>
#define ASSERT_W(expr) \
if(!expr) \
{ ... | 60.766667 | 109 | 0.225453 | Gregofi |
e61391e31b4b71732ebe4077cca0abc02da793b0 | 1,827 | cpp | C++ | src/2DXngine.Engine/Utils/Math/RectangleI.cpp | Harunx9/2DXngine | 300a8c1689def00afd84a9328546e6e596ee34d2 | [
"MIT"
] | 4 | 2017-09-06T15:00:25.000Z | 2021-03-08T09:39:04.000Z | src/2DXngine.Engine/Utils/Math/RectangleI.cpp | Harunx9/2DXngine | 300a8c1689def00afd84a9328546e6e596ee34d2 | [
"MIT"
] | 5 | 2017-04-09T13:20:24.000Z | 2017-06-11T16:15:31.000Z | src/2DXngine.Engine/Utils/Math/RectangleI.cpp | Harunx9/2DXngine | 300a8c1689def00afd84a9328546e6e596ee34d2 | [
"MIT"
] | 1 | 2017-05-22T20:24:30.000Z | 2017-05-22T20:24:30.000Z | #include "RectangleI.h"
RectangleI::RectangleI():
_x(0),
_y(0),
_width(0),
_heihgt(0)
{
}
RectangleI::RectangleI(int x, int y, int width, int height) :
_x(x),
_y(y),
_width(width),
_heihgt(height)
{
}
RectangleI::~RectangleI()
{
}
int RectangleI::get_x() const
{
return this->_x;
... | 16.459459 | 61 | 0.599891 | Harunx9 |
e618695dddc1ad0c3d0c4d08db3224d99641925d | 1,817 | cpp | C++ | Fondamenti di Programmazione/Test007_Tartaglia/compito.cpp | NamaWho/University | 5723e113e8ef082d50201c545ea901cc0eb87613 | [
"MIT"
] | 1 | 2021-01-10T10:03:58.000Z | 2021-01-10T10:03:58.000Z | Fondamenti di Programmazione/Test007_Tartaglia/compito.cpp | NamaWho/University | 5723e113e8ef082d50201c545ea901cc0eb87613 | [
"MIT"
] | null | null | null | Fondamenti di Programmazione/Test007_Tartaglia/compito.cpp | NamaWho/University | 5723e113e8ef082d50201c545ea901cc0eb87613 | [
"MIT"
] | null | null | null | //
// Created by danie on 28/12/2020.
//
#include "compito.h"
#include <iostream>
#include <iomanip>
using namespace std;
Tartaglia::Tartaglia(int ord) {
order = (ord < 0) ? 0 : ord;
triangle = new int [(order+1)*(order+1)];
triangle[0] = 1;
for (int i = 1; i < (order+1); ++i) {
for (int j =... | 21.127907 | 109 | 0.451844 | NamaWho |
e6196c1c24ad2bc2e08e92b9909715d1cdcd1407 | 392 | hpp | C++ | examples/sponza/components/material_component.hpp | EduRenesto/abcg | 4f7ab2d02e20e2a9351af03c34360a7629c219d1 | [
"MIT"
] | null | null | null | examples/sponza/components/material_component.hpp | EduRenesto/abcg | 4f7ab2d02e20e2a9351af03c34360a7629c219d1 | [
"MIT"
] | null | null | null | examples/sponza/components/material_component.hpp | EduRenesto/abcg | 4f7ab2d02e20e2a9351af03c34360a7629c219d1 | [
"MIT"
] | null | null | null | #ifndef __SPONZA_MATERIAL_COMPONENT_HPP
#define __SPONZA_MATERIAL_COMPONENT_HPP
#include <GL/glew.h>
#include "../ecs.hpp"
/*
* For now, this `MaterialComponent` is just a struct that
* holds the handle for the OpenGL shader program.
*/
struct MaterialComponent {
ECS_DECLARE_TYPE
std::string asset_name;
} __... | 18.666667 | 58 | 0.767857 | EduRenesto |
e61c4312285d97833b205c56d0170ccc02a6de12 | 20,806 | cpp | C++ | src/vidhrdw/megasys1.cpp | pierrelouys/PSP-MAME4ALL | 54374b0579b7e2377f015ac155d8f519addfaa1a | [
"Unlicense"
] | 1 | 2021-01-25T20:16:33.000Z | 2021-01-25T20:16:33.000Z | src/vidhrdw/megasys1.cpp | pierrelouys/PSP-MAME4ALL | 54374b0579b7e2377f015ac155d8f519addfaa1a | [
"Unlicense"
] | 1 | 2021-05-24T20:28:35.000Z | 2021-05-25T14:44:54.000Z | src/vidhrdw/megasys1.cpp | PSP-Archive/PSP-MAME4ALL | 54374b0579b7e2377f015ac155d8f519addfaa1a | [
"Unlicense"
] | null | null | null | #define EXTRA_MEM_PATCH
#ifdef DREAMCAST
#include<kos.h>
#endif
/***************************************************************************
-= Jaleco Mega System 1 =-
driver by Luca Elia (eliavit@unina.it)
********** There are 3 scrolling layers, 2 bytes per tile info:
* Note: MS1-Z has 2 layers only... | 26.674359 | 116 | 0.625445 | pierrelouys |
e61d5499a00029d8f687907d00b8da5a7225f340 | 558 | cpp | C++ | src/PAT/P1046.cpp | TDYe123/Algorithm | 9c7cc2b2b79db7245846affc5b263049fd866c87 | [
"MIT"
] | 1 | 2019-05-04T15:44:41.000Z | 2019-05-04T15:44:41.000Z | src/PAT/P1046.cpp | TDYe123/Algorithm | 9c7cc2b2b79db7245846affc5b263049fd866c87 | [
"MIT"
] | null | null | null | src/PAT/P1046.cpp | TDYe123/Algorithm | 9c7cc2b2b79db7245846affc5b263049fd866c87 | [
"MIT"
] | null | null | null | #include<bits/stdc++.h>
using namespace std;
const int maxn = 100010;
int arr[maxn], N, M, clk[maxn], anticlk[maxn];
int main() {
cin >> N;
for(int i=1; i<=N; i++)
cin >> arr[i];
clk[1] = 0;
for(int i=2; i<=N; i++) {
clk[i] = clk[i-1] + arr[i-1];
}
anticlk[1] = 0;
anticlk[N] = arr[N];
for(int ... | 19.928571 | 57 | 0.476703 | TDYe123 |
e62150c78e5e5700e9bb25a874027f526b570839 | 566 | cc | C++ | crawl-ref/source/catch2-tests/test_species.cc | petercordia/crawl | c18c9092ac65e4306219b2c8d675610b0e127db0 | [
"CC0-1.0"
] | 7 | 2020-01-25T06:34:02.000Z | 2021-12-02T15:22:56.000Z | crawl-ref/source/catch2-tests/test_species.cc | petercordia/crawl | c18c9092ac65e4306219b2c8d675610b0e127db0 | [
"CC0-1.0"
] | 43 | 2019-06-24T11:43:20.000Z | 2020-05-19T00:06:01.000Z | crawl-ref/source/catch2-tests/test_species.cc | petercordia/crawl | c18c9092ac65e4306219b2c8d675610b0e127db0 | [
"CC0-1.0"
] | 3 | 2019-10-10T15:06:51.000Z | 2021-07-09T11:54:02.000Z | #include "catch.hpp"
#include "AppHdr.h"
#include "species.h"
TEST_CASE( "Random draconian species are not removed", "[single-file]" ) {
for (int i = 0; i < 100; ++i)
{
auto species = random_draconian_colour();
REQUIRE( !species_is_removed(species) );
}
}
TEST_CASE( "Random draconian spec... | 25.727273 | 81 | 0.618375 | petercordia |
e62173c0a94ac05263585de5a1b03599edcd88a0 | 781 | cc | C++ | src/recursion/factorial.cc | FlipMatias/AlgorithmDataStructures | 0e576ad8149f22f151b84a0fb54e9e46dc15c4a2 | [
"MIT"
] | null | null | null | src/recursion/factorial.cc | FlipMatias/AlgorithmDataStructures | 0e576ad8149f22f151b84a0fb54e9e46dc15c4a2 | [
"MIT"
] | 1 | 2020-09-28T07:46:44.000Z | 2020-09-28T07:47:22.000Z | src/recursion/factorial.cc | FlipMatias/AlgorithmDataStructures | 0e576ad8149f22f151b84a0fb54e9e46dc15c4a2 | [
"MIT"
] | null | null | null | #include <stdio.h>
#include <stdint.h>
template <typename T = uint64_t>
static T factorial(T num)
{
if (num == 0) return 1;
if (num > 1) {
return factorial(num - 1) * num;
} else {
return num;
}
}
//compile-time recursive
template <uint64_t num>
static uint64_t cfactorial()
{
if... | 17.355556 | 48 | 0.517286 | FlipMatias |
e622367b2a1fe08305f3b0f74fd5eba9e723a271 | 314 | cpp | C++ | Tutorial/1.Hello World.cpp | azminawwar/tutorial_cpp | 0ec79e9c7f5f77bab38bc23dfc9e81a70897faa8 | [
"MIT"
] | 12 | 2020-03-06T04:18:13.000Z | 2021-11-02T01:28:21.000Z | Tutorial/1.Hello World.cpp | azminawwar/tutorial_cpp | 0ec79e9c7f5f77bab38bc23dfc9e81a70897faa8 | [
"MIT"
] | 1 | 2020-10-02T10:02:37.000Z | 2020-10-02T10:02:37.000Z | Tutorial/1.Hello World.cpp | azminawwar/tutorial_cpp | 0ec79e9c7f5f77bab38bc23dfc9e81a70897faa8 | [
"MIT"
] | 9 | 2019-11-02T09:33:47.000Z | 2021-12-16T14:24:49.000Z | #include <iostream>
using namespace std;
//int main wajib dalam sebuah codingan cpp, dia sebagai "body" utama c++
int main()
{
//dalam cpp untuk meng output kan sebuah kalimat, diperlukan cout<< dengan tulisan dalam tanda kutip,
//karna ia dibaca sebagai string
cout<<"Halo Dunia !";
return 0;
}
| 28.545455 | 105 | 0.700637 | azminawwar |
e6274b03857b217d22746751196094b9a26d33c7 | 3,461 | hpp | C++ | src/_common/_invoke.hpp | ombre5733/weos | 2c3edef042fa80baa7c8fb968ba3104b7119cf2d | [
"BSD-2-Clause"
] | 11 | 2015-10-06T21:00:30.000Z | 2021-07-27T05:54:44.000Z | src/_common/_invoke.hpp | ombre5733/weos | 2c3edef042fa80baa7c8fb968ba3104b7119cf2d | [
"BSD-2-Clause"
] | null | null | null | src/_common/_invoke.hpp | ombre5733/weos | 2c3edef042fa80baa7c8fb968ba3104b7119cf2d | [
"BSD-2-Clause"
] | 1 | 2015-10-03T03:51:28.000Z | 2015-10-03T03:51:28.000Z | /*******************************************************************************
WEOS - Wrapper for embedded operating systems
Copyright (c) 2013-2016, Manuel Freiberger
All rights reserved.
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the foll... | 30.095652 | 81 | 0.68015 | ombre5733 |
e627dba8daa108c044d04650fd2f1dbde3c4a527 | 776 | hpp | C++ | structures/template.hpp | pat-laugh/websson-libraries | c5c99a98270dee45fcd9ec4e7f03e2e74e3b1ce2 | [
"MIT"
] | null | null | null | structures/template.hpp | pat-laugh/websson-libraries | c5c99a98270dee45fcd9ec4e7f03e2e74e3b1ce2 | [
"MIT"
] | 33 | 2017-04-25T21:53:59.000Z | 2017-07-14T13:30:29.000Z | structures/template.hpp | pat-laugh/websson-libraries | c5c99a98270dee45fcd9ec4e7f03e2e74e3b1ce2 | [
"MIT"
] | null | null | null | //MIT License
//Copyright 2017 Patrick Laughrea
#pragma once
#include "base.hpp"
#include "thead.hpp"
#include "tuple.hpp"
#include "webss.hpp"
namespace webss
{
class Template : public Thead
{
private:
using base = Thead;
public:
Webss body, content;
Template(base thead, Tuple tuple, WebssType type = Web... | 29.846154 | 172 | 0.67268 | pat-laugh |
e62b340f6802c3f73254e4815bf971f220b9592a | 15,061 | cpp | C++ | test/script/types_test.cpp | fuersten/sun_ray | b882d67cd9747f61b50def4c1414e7552ba917c0 | [
"BSD-3-Clause"
] | 2 | 2021-03-28T21:36:36.000Z | 2021-08-10T14:44:04.000Z | test/script/types_test.cpp | fuersten/sun_ray | b882d67cd9747f61b50def4c1414e7552ba917c0 | [
"BSD-3-Clause"
] | null | null | null | test/script/types_test.cpp | fuersten/sun_ray | b882d67cd9747f61b50def4c1414e7552ba917c0 | [
"BSD-3-Clause"
] | null | null | null | //
// types_test.cpp
// sun_ray_test
//
// Created by Lars-Christian Fürstenberg on 28.01.20.
// Copyright © 2020 Lars-Christian Fürstenberg. All rights reserved.
//
#include <sun_ray/script/objects/color.h>
#include <sun_ray/script/types.h>
#include <sstream>
#include <catch2/catch.hpp>
using namespace std::st... | 32.884279 | 120 | 0.65248 | fuersten |
e62b975e4dd2b74116d1ce41e3243301a3affcd0 | 8,267 | cpp | C++ | src/neo/any_iterator.test.cpp | david-bakin/neo-fun | 4fc4318bb1bb5aad1335c6dfab6a2f61dcc889a8 | [
"BSL-1.0"
] | null | null | null | src/neo/any_iterator.test.cpp | david-bakin/neo-fun | 4fc4318bb1bb5aad1335c6dfab6a2f61dcc889a8 | [
"BSL-1.0"
] | null | null | null | src/neo/any_iterator.test.cpp | david-bakin/neo-fun | 4fc4318bb1bb5aad1335c6dfab6a2f61dcc889a8 | [
"BSL-1.0"
] | null | null | null | #include "./any_iterator.hpp"
#include "./range_archetypes.hpp"
#include "./test_concept.hpp"
#include "./utf8.hpp"
#include <deque>
#include <forward_list>
#include <list>
#include <catch2/catch.hpp>
NEO_TEST_CONCEPT(neo::input_iterator<neo::any_input_iterator<int>>);
NEO_TEST_CONCEPT(neo::input_iterator<neo::any_... | 38.451163 | 98 | 0.660215 | david-bakin |
e62bf7b59cce073545e9a6674cd835545dbe52dd | 4,203 | cpp | C++ | packages/zed/components/ZedImuReader.cpp | stereoboy/isaac_sdk_20191213 | 73c863254e626c8d498870189fbfb20be4e10fb3 | [
"FSFAP"
] | 1 | 2020-04-14T13:55:16.000Z | 2020-04-14T13:55:16.000Z | packages/zed/components/ZedImuReader.cpp | stereoboy/isaac_sdk_20191213 | 73c863254e626c8d498870189fbfb20be4e10fb3 | [
"FSFAP"
] | 4 | 2020-09-25T22:34:29.000Z | 2022-02-09T23:45:12.000Z | packages/zed/components/ZedImuReader.cpp | stereoboy/isaac_sdk_20191213 | 73c863254e626c8d498870189fbfb20be4e10fb3 | [
"FSFAP"
] | 1 | 2020-07-02T11:51:17.000Z | 2020-07-02T11:51:17.000Z | /*
Copyright (c) 2019, NVIDIA CORPORATION. All rights reserved.
NVIDIA CORPORATION and its licensors retain all intellectual property
and proprietary rights in and to this software, related documentation
and any modifications thereto. Any use, reproduction, disclosure or
distribution of this software and related docum... | 40.413462 | 97 | 0.758268 | stereoboy |
e631b5103ed04fe34a289cc4bf1c60f416edcb16 | 1,144 | cc | C++ | 38/test.cc | buyno/CodingInterview2 | 9765010e3e8aa96df5cc0456f616fd764a4385a8 | [
"Apache-2.0"
] | null | null | null | 38/test.cc | buyno/CodingInterview2 | 9765010e3e8aa96df5cc0456f616fd764a4385a8 | [
"Apache-2.0"
] | null | null | null | 38/test.cc | buyno/CodingInterview2 | 9765010e3e8aa96df5cc0456f616fd764a4385a8 | [
"Apache-2.0"
] | null | null | null | #include <string>
#include <sstream>
#include <vector>
#include <set>
using namespace std;
class Solution
{
public:
vector<string> permutation(string s)
{
vector<string> vec;
set<string> tmp; //set保存结果,并自动去重
if (s.empty())
return vec;
permutation(s, 0, tmp);
... | 20.428571 | 60 | 0.453671 | buyno |
e63859abf76bd0c896555a67a6def7eea736e707 | 7,898 | hpp | C++ | headers/VisualREPL.hpp | bemcho/home_ai_reloaded_cmake | 52fbe70f168ad3f862361fb8b3e59bbdd7c950da | [
"MIT"
] | 1 | 2018-05-17T16:02:25.000Z | 2018-05-17T16:02:25.000Z | headers/VisualREPL.hpp | bemcho/home_ai_reloaded_cmake | 52fbe70f168ad3f862361fb8b3e59bbdd7c950da | [
"MIT"
] | null | null | null | headers/VisualREPL.hpp | bemcho/home_ai_reloaded_cmake | 52fbe70f168ad3f862361fb8b3e59bbdd7c950da | [
"MIT"
] | null | null | null | #pragma once
#include <functional>
#include <random>
#include <string>
#include <thread>
#include "tbb/parallel_invoke.h"
#include "tbb/mutex.h"
#include "ClipsAdapter.hpp"
#include "VisualContextAnnotator.hpp"
namespace hai {
using namespace std;
using namespace cv;
class VisualREPL {
public:
VisualR... | 37.43128 | 117 | 0.54001 | bemcho |
e63961846576da44d114e612682983e49128ac2f | 542 | cpp | C++ | Code/EnginePlugins/ProcGenPlugin/Tasks/Implementation/PlacementData.cpp | alinoctavian/ezEngine | 0312c8d777c05ac58911f3fa879e4fd7efcfcb66 | [
"MIT"
] | 1 | 2021-06-23T14:44:02.000Z | 2021-06-23T14:44:02.000Z | Code/EnginePlugins/ProcGenPlugin/Tasks/Implementation/PlacementData.cpp | alinoctavian/ezEngine | 0312c8d777c05ac58911f3fa879e4fd7efcfcb66 | [
"MIT"
] | null | null | null | Code/EnginePlugins/ProcGenPlugin/Tasks/Implementation/PlacementData.cpp | alinoctavian/ezEngine | 0312c8d777c05ac58911f3fa879e4fd7efcfcb66 | [
"MIT"
] | 1 | 2022-03-28T15:57:46.000Z | 2022-03-28T15:57:46.000Z | #include <ProcGenPluginPCH.h>
#include <ProcGenPlugin/Components/VolumeCollection.h>
#include <ProcGenPlugin/Tasks/PlacementData.h>
namespace ezProcGenInternal
{
PlacementData::PlacementData() = default;
PlacementData::~PlacementData() = default;
void PlacementData::Clear()
{
m_pPhysicsModule = nullptr;
... | 22.583333 | 54 | 0.741697 | alinoctavian |
e63ae5238ce87ce64d3738da040d294ac18ba4a6 | 712 | cpp | C++ | USACO Bronze/December 2014 Contest/marathon.cpp | Alecs-Li/Competitive-Programming | 39941ff8e2c8994abbae8c96a1ed0a04b10058b8 | [
"MIT"
] | 1 | 2021-07-06T02:14:03.000Z | 2021-07-06T02:14:03.000Z | USACO Bronze/December 2014 Contest/marathon.cpp | Alex01890-creator/competitive-programming | 39941ff8e2c8994abbae8c96a1ed0a04b10058b8 | [
"MIT"
] | null | null | null | USACO Bronze/December 2014 Contest/marathon.cpp | Alex01890-creator/competitive-programming | 39941ff8e2c8994abbae8c96a1ed0a04b10058b8 | [
"MIT"
] | null | null | null | #include <iostream>
#include <vector>
using namespace std;
int main(){
freopen("marathon.in", "r", stdin);
freopen("marathon.out", "w", stdout);
int n; cin >> n;
vector<pair<int, int>> v;
int arr[n-1];
for(int a=0; a<n; a++){
int b, c; cin >> b >> c;
v.push_back(make_pair(b, c)... | 25.428571 | 116 | 0.485955 | Alecs-Li |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.